<?php 
/*
 * @version $Id: zh_TW.php 18513 2012-05-25 06:31:03Z moyo $ 
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 -------------------------------------------------------------------------
 */
//zh_TW

$LANG=array();


$LANG['backup'][0]="轉存SQL"; 
$LANG['backup'][1]="轉存XML"; 
$LANG['backup'][11]="大小"; 
$LANG['backup'][13]="檢視/下載"; 
$LANG['backup'][16]="由備份檔覆蓋還原目前的資料庫:"; 
$LANG['backup'][17]="刪除這個檔案 ?"; 
$LANG['backup'][18]="備份資料庫 ?"; 
$LANG['backup'][21]="文件已經存在"; 
$LANG['backup'][22]="找不到位元組"; 
$LANG['backup'][23]="Mysql 錯誤從"; 
$LANG['backup'][24]="自動重定向，否則點選"; 

$LANG['bookmark'][1]="書籤"; 
$LANG['bookmark'][2]="載入部份的書籤"; 
$LANG['bookmark'][3]="您目前沒有任何書籤的記錄."; 
$LANG['bookmark'][4]="新增書籤"; 
$LANG['bookmark'][5]="公用書籤"; 
$LANG['bookmark'][6]="預設檢視"; 

$LANG['buttons'][0]="搜尋"; 
$LANG['buttons'][2]="確定"; 
$LANG['buttons'][3]="分配"; 
$LANG['buttons'][4]="安裝"; 
$LANG['buttons'][5]="移除"; 
$LANG['buttons'][6]="刪除"; 
$LANG['buttons'][7]="更新"; 
$LANG['buttons'][8]="新增"; 
$LANG['buttons'][9]="連接"; 
$LANG['buttons'][10]="中斷"; 
$LANG['buttons'][11]="下一步"; 
$LANG['buttons'][12]="上一步"; 
$LANG['buttons'][13]="返回"; 
$LANG['buttons'][14]="更新"; 
$LANG['buttons'][15]="日程表"; 
$LANG['buttons'][16]="空白"; 
$LANG['buttons'][17]="反向選取"; 
$LANG['buttons'][18]="全選"; 
$LANG['buttons'][19]="取消全部"; 
$LANG['buttons'][20]="移動"; 
$LANG['buttons'][21]="恢復"; 
$LANG['buttons'][22]="清除"; 
$LANG['buttons'][23]="展示"; 
$LANG['buttons'][24]="向上"; 
$LANG['buttons'][25]="向下"; 
$LANG['buttons'][26]="送出"; 
$LANG['buttons'][27]="目前頁面以 PDF 導出"; 
$LANG['buttons'][28]="目前頁面以 SLK 導出"; 
$LANG['buttons'][29]="所有頁面以 PDF 導出"; 
$LANG['buttons'][30]="所有頁面以 SLK 導出"; 
$LANG['buttons'][31]="導出"; 
$LANG['buttons'][32]="結束"; 
$LANG['buttons'][33]="開始"; 
$LANG['buttons'][34]="取消"; 
$LANG['buttons'][35]="刪除所有預排"; 
$LANG['buttons'][37]="導入"; 
$LANG['buttons'][38]="解鎖"; 
$LANG['buttons'][39]="取代"; 
$LANG['buttons'][40]="顯示全部"; 
$LANG['buttons'][41]="啟動"; 
$LANG['buttons'][42]="停止"; 
$LANG['buttons'][43]="瀏覽"; 
$LANG['buttons'][44]="目前頁面以 CSV 導出"; 
$LANG['buttons'][45]="所有頁面以 CSV 導出"; 
$LANG['buttons'][48]="移轉"; 
$LANG['buttons'][49]="保存"; 
$LANG['buttons'][50]="測試"; 
$LANG['buttons'][51]="存檔"; 
$LANG['buttons'][52]="讀取"; 
$LANG['buttons'][53]="清除"; 
$LANG['buttons'][54]="重複"; 
$LANG['buttons'][55]="第一"; 
$LANG['buttons'][56]="最後"; 
$LANG['buttons'][57]="執行"; 
$LANG['buttons'][58]="更新"; 
$LANG['buttons'][59]="分開"; 
$LANG['buttons'][60]="關閉視窗"; 
$LANG['buttons'][61]="重建"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 
$LANG['calendar'][3]="遞迴"; 
$LANG['calendar'][4]="結束時間"; 
$LANG['calendar'][5]="時間範圍"; 
$LANG['calendar'][6]="新增一個日程表"; 
$LANG['calendar'][7]="日"; 
$LANG['calendar'][8]="無法新增重複已存在的範圍"; 
$LANG['calendar'][10]="時間範圍"; 
$LANG['calendar'][11]="關閉時間"; 
$LANG['calendar'][12]="日(s)"; 
$LANG['calendar'][13]="週(s)"; 
$LANG['calendar'][14]="月"; // singular (plural) like month(s)
$LANG['calendar'][15]="年(s)"; 
$LANG['calendar'][16]="現在"; 
$LANG['calendar'][17]="指定日期"; 
$LANG['calendar'][18]="上週日"; 
$LANG['calendar'][19]="上週一"; 
$LANG['calendar'][20]="上週二"; 
$LANG['calendar'][21]="上週三"; 
$LANG['calendar'][22]="上週四"; 
$LANG['calendar'][23]="上週五"; 
$LANG['calendar'][24]="上週六"; 
$LANG['calendar'][25]="從本月開始"; 
$LANG['calendar'][26]="從今年開始"; 
$LANG['calendar'][27]="今天"; 

$LANG['calendarD'][0]="一"; 
$LANG['calendarD'][1]="二"; 
$LANG['calendarD'][2]="三"; 
$LANG['calendarD'][3]="四"; 
$LANG['calendarD'][4]="五"; 
$LANG['calendarD'][5]="六"; 
$LANG['calendarD'][6]="日"; 

$LANG['calendarDay'][0]="星期天"; 
$LANG['calendarDay'][1]="星期一"; 
$LANG['calendarDay'][2]="星期二"; 
$LANG['calendarDay'][3]="星期三"; 
$LANG['calendarDay'][4]="星期四"; 
$LANG['calendarDay'][5]="星期五"; 
$LANG['calendarDay'][6]="星期六"; 

$LANG['calendarM'][0]="1月"; 
$LANG['calendarM'][1]="2月"; 
$LANG['calendarM'][2]="3月"; 
$LANG['calendarM'][3]="4月"; 
$LANG['calendarM'][4]="5月"; 
$LANG['calendarM'][5]="6月"; 
$LANG['calendarM'][6]="7月"; 
$LANG['calendarM'][7]="8月"; 
$LANG['calendarM'][8]="9月"; 
$LANG['calendarM'][9]="10月"; 
$LANG['calendarM'][10]="11月"; 
$LANG['calendarM'][11]="12月"; 

$LANG['cartridges'][0]="墨水夾"; 
$LANG['cartridges'][1]="墨水型號"; 
$LANG['cartridges'][2]="墨水型號"; 
$LANG['cartridges'][3]="錯誤總計"; 
$LANG['cartridges'][9]="沒有墨水夾"; 
$LANG['cartridges'][10]="碳粉"; 
$LANG['cartridges'][11]="噴墨"; 
$LANG['cartridges'][12]="墨水夾類型"; 
$LANG['cartridges'][13]="新的"; 
$LANG['cartridges'][14]="用過的"; 
$LANG['cartridges'][15]="舊"; 
$LANG['cartridges'][16]="墨水夾(s)"; 
$LANG['cartridges'][20]="新的"; 
$LANG['cartridges'][21]="用過的"; 
$LANG['cartridges'][22]="舊"; 
$LANG['cartridges'][24]="新增日期"; 
$LANG['cartridges'][27]="在"; 
$LANG['cartridges'][29]="用完"; 
$LANG['cartridges'][32]="兼容印表機型號"; 
$LANG['cartridges'][33]="用過的墨水夾"; 
$LANG['cartridges'][34]="可用墨水夾？"; 
$LANG['cartridges'][35]="舊墨水夾"; 
$LANG['cartridges'][37]="色帶"; 
$LANG['cartridges'][39]="印表機計數器(頁數)"; 
$LANG['cartridges'][40]="平均庫存時間"; 
$LANG['cartridges'][41]="平均使用時間"; 
$LANG['cartridges'][42]="平均列印頁數"; 

$LANG['central'][1]="基於安全原因，請更改預設的帳號密碼"; 
$LANG['central'][2]="前"; 
$LANG['central'][4]="沒有事件"; 
$LANG['central'][5]="主頁"; 
$LANG['central'][6]="登出"; 
$LANG['central'][7]="幫助"; 
$LANG['central'][8]="新增的內容"; 
$LANG['central'][9]="您 進行中 的問題單"; 
$LANG['central'][10]="新增新問題單"; 
$LANG['central'][12]="個人檢視"; 
$LANG['central'][13]="全部檢視"; 
$LANG['central'][14]="群組檢視"; 
$LANG['central'][17]="您被退回的問題單"; 
$LANG['central'][18]="您 待結案 的問題單"; 
$LANG['central'][19]="您 待生效 的問題單"; 

$LANG['change'][0]="變更"; 
$LANG['change'][1]="建立這個問題單的變更"; 
$LANG['change'][2]="建立這個問題的變更"; 
$LANG['change'][3]="控制清單"; 
$LANG['change'][4]="部署計劃"; 
$LANG['change'][5]="備份計劃"; 
$LANG['change'][6]="檢視清單"; 
$LANG['change'][7]="計劃"; 
$LANG['change'][8]="評估"; 
$LANG['change'][9]="批准"; 
$LANG['change'][10]="測試"; 
$LANG['change'][11]="條件"; 
$LANG['change'][12]="套用"; 
$LANG['change'][13]="已捨棄"; 
$LANG['change'][14]="修改"; 

$LANG['choice'][0]="否"; 
$LANG['choice'][1]="是"; 
$LANG['choice'][2]="或"; 
$LANG['choice'][3]="且"; 

$LANG['common'][0]="沒有名稱"; 
$LANG['common'][1]="項目"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="顯示已刪除項目"; 
$LANG['common'][4]="網路"; 
$LANG['common'][5]="製造商"; 
$LANG['common'][6]="模板名稱"; 
$LANG['common'][7]="選項模板"; 
$LANG['common'][8]="處理模板…"; 
$LANG['common'][9]="新增一塊模板…"; 
$LANG['common'][10]="硬體技術負責範圍"; 
$LANG['common'][11]="限制視圖"; 
$LANG['common'][12]="設定"; 
$LANG['common'][13]="模板"; 
$LANG['common'][14]="模板(s)"; 
$LANG['common'][15]="地點"; 
$LANG['common'][16]="名稱"; 
$LANG['common'][17]="類型"; 
$LANG['common'][18]="聯絡人"; 
$LANG['common'][19]="序號"; 
$LANG['common'][20]="財產編號"; 
$LANG['common'][21]="聯絡電話"; 
$LANG['common'][22]="樣式"; 
$LANG['common'][23]="執行成功"; 
$LANG['common'][24]="沒有選定的項目或不正確的操作"; 
$LANG['common'][25]="備註"; 
$LANG['common'][26]="上次更新日期"; 
$LANG['common'][27]="日期"; 
$LANG['common'][28]="已刪除"; 
$LANG['common'][29]="插件"; 
$LANG['common'][30]="新的項目"; 
$LANG['common'][31]="空白的模板"; 
$LANG['common'][32]="特徵"; 
$LANG['common'][33]="共計"; 
$LANG['common'][34]="使用者"; 
$LANG['common'][35]="群組"; 
$LANG['common'][36]="類別"; 
$LANG['common'][37]="作者"; 
$LANG['common'][38]="使用統一的管理"; 
$LANG['common'][39]="依連線次數複製項目"; 
$LANG['common'][40]="你真的要取消這個物件的全局設定 ?"; 
$LANG['common'][41]="警示郵件"; 
$LANG['common'][42]="行動電話"; 
$LANG['common'][43]="名字"; 
$LANG['common'][44]="預設值"; 
$LANG['common'][45]="MB 最大"; 
$LANG['common'][46]="電子名片"; 
$LANG['common'][47]="進行"; 
$LANG['common'][48]="姓"; 
$LANG['common'][49]="無"; 
$LANG['common'][50]="確定刪除 ?"; 
$LANG['common'][51]="全名"; 
$LANG['common'][52]="伺服器"; 
$LANG['common'][53]="清單"; 
$LANG['common'][54]="項目不存在"; 
$LANG['common'][55]="你確定要刪除這些項目?"; 
$LANG['common'][56]="中控台"; 
$LANG['common'][57]="標題"; 
$LANG['common'][58]="最大值"; 
$LANG['common'][59]="全部"; 
$LANG['common'][60]="啟用"; 
$LANG['common'][61]="不明的錯誤"; 
$LANG['common'][62]="其它"; 
$LANG['common'][63]="錯誤(s)"; 
$LANG['common'][64]="管理"; 
$LANG['common'][65]="接口"; 
$LANG['common'][66]="全部"; 
$LANG['common'][67]="其它"; 
$LANG['common'][68]="橫向"; 
$LANG['common'][69]="直向"; 
$LANG['common'][70]="項目新增成功"; 
$LANG['common'][71]="項目更新成功"; 
$LANG['common'][72]="項目刪除成功"; 
$LANG['common'][73]="項目清除成功"; 
$LANG['common'][74]="項目回復成功"; 
$LANG['common'][75]="可用性"; 
$LANG['common'][76]="公開"; 
$LANG['common'][77]="私人"; 
$LANG['common'][78]="設定為公開"; 
$LANG['common'][79]="設定為私人"; 
$LANG['common'][80]="讀取中..."; 
$LANG['common'][81]="不顯示已刪除的項目"; 
$LANG['common'][82]="Mb"; 
$LANG['common'][83]="您沒有執行這項工作的權限."; 
$LANG['common'][84]="禁止變更Flag。發現連結項目."; 
$LANG['common'][85]="設定子程序可以看見"; 
$LANG['common'][86]="您未被授權變更子程序可見的設定."; 
$LANG['common'][87]="新帖"; 
$LANG['common'][88]="個人"; 
$LANG['common'][89]="未安裝"; 
$LANG['common'][90]="目的"; 
$LANG['common'][91]="無法變更這個屬性。它繼承了父系物件。"; 
$LANG['common'][92]="供選擇的使用者名稱"; 
$LANG['common'][93]="新的子標題"; 
$LANG['common'][94]="URL"; 
$LANG['common'][95]="依"; 
$LANG['common'][96]="項目"; 
$LANG['common'][97]="連結至"; 
$LANG['common'][98]="重複"; 
$LANG['common'][99]="日期"; 
$LANG['common'][100]="次數"; 
$LANG['common'][101]="最後編輯由"; 
$LANG['common'][102]="繼承父系實體"; 
$LANG['common'][103]="實施者"; 
$LANG['common'][104]="監督"; 
$LANG['common'][105]="警報"; 
$LANG['common'][106]="至少有一個欄位有一個不正確的值"; 
$LANG['common'][107]="平均"; 
$LANG['common'][108]="遠端訪問密鑰"; 
$LANG['common'][109]="負責的硬體群組"; 
$LANG['common'][110]="實體沒有變更"; 
$LANG['common'][111]="使用的項目"; 
$LANG['common'][112]="管理的項目"; 
$LANG['common'][113]="可見"; 
$LANG['common'][114]="ID標籤"; 
$LANG['common'][115]="週期性"; 
$LANG['common'][116]="新增一個目標"; 
$LANG['common'][117]="執行的操作 部分 成功"; 
$LANG['common'][118]="操作失敗"; 
$LANG['common'][119]="失敗"; 
$LANG['common'][120]="注意！你是不是該項目的作者。刪除該可能會導致存取該項目失敗。"; 
$LANG['common'][121]="授權問題"; 
$LANG['common'][123]="授權債務人"; 

$LANG['computers'][0]="儲存裝置"; 
$LANG['computers'][1]="磁碟可用空間 %"; 
$LANG['computers'][2]="可用容量"; 
$LANG['computers'][3]="全部容量"; 
$LANG['computers'][4]="檔案系統"; 
$LANG['computers'][5]="掛載點"; 
$LANG['computers'][6]="分割"; 
$LANG['computers'][7]="新增儲存裝置"; 
$LANG['computers'][8]="儲存裝置"; 
$LANG['computers'][9]="作業系統"; 
$LANG['computers'][10]="作業系統的序號"; 
$LANG['computers'][11]="作業系統的產品 ID"; 
$LANG['computers'][14]="插入"; 
$LANG['computers'][23]="記憶體類型"; 
$LANG['computers'][24]="記憶體大小"; 
$LANG['computers'][25]="硬碟大小"; 
$LANG['computers'][36]="硬碟類型"; 
$LANG['computers'][37]="沒有連接的顯示器。"; 
$LANG['computers'][38]="沒有連接的印表機"; 
$LANG['computers'][46]="虛擬機"; 
$LANG['computers'][47]="沒有連接的設備"; 
$LANG['computers'][48]="地點已更新。 連接的項目被移動至同一個地點。"; 
$LANG['computers'][49]="聯絡人更新。 和聯絡關聯的項目已被更新。"; 
$LANG['computers'][50]="使用者或群組更新。連接的項目被調至相同的值。"; 
$LANG['computers'][51]="更新來源"; 
$LANG['computers'][52]="作業系統版本"; 
$LANG['computers'][53]="服務套件"; 
$LANG['computers'][54]="沒有連接的電話"; 
$LANG['computers'][55]="新增虛擬機"; 
$LANG['computers'][56]="狀態已更新. 已連線的裝置被更新為現在的狀態."; 
$LANG['computers'][57]="虛擬機"; 
$LANG['computers'][58]="UUID"; 
$LANG['computers'][59]="沒有虛擬機與電腦關聯"; 
$LANG['computers'][60]="虛擬化模式"; 
$LANG['computers'][61]="處理器數量"; 
$LANG['computers'][62]="虛擬化系統"; 
$LANG['computers'][63]="虛擬機的狀態"; 
$LANG['computers'][64]="機器"; 
$LANG['computers'][65]="列出主機名單"; 
$LANG['computers'][66]="列出虛擬機名單"; 
$LANG['computers'][67]="虛擬化系統"; 
$LANG['computers'][68]="虛擬機型號"; 
$LANG['computers'][69]="虛擬機的狀態"; 

$LANG['connect'][0]="直接連接"; 
$LANG['connect'][1]="未連接。"; 
$LANG['connect'][2]="直接連接"; 
$LANG['connect'][3]="直接連接"; 
$LANG['connect'][4]="沒有直接連繫"; 
$LANG['connect'][15]="以下項目將被自動更新"; 
$LANG['connect'][16]="警告!! 以下兩個項目的硬體不符"; 

$LANG['consumables'][0]="消耗品"; 
$LANG['consumables'][1]="庫存"; 
$LANG['consumables'][2]="參考"; 
$LANG['consumables'][3]="耗材型號"; 
$LANG['consumables'][4]="耗材型號"; 
$LANG['consumables'][7]="沒有發現消耗品"; 
$LANG['consumables'][9]="沒有消耗品"; 
$LANG['consumables'][12]="消耗品種類"; 
$LANG['consumables'][14]="新"; 
$LANG['consumables'][16]="消耗品(s)"; 
$LANG['consumables'][20]="新的"; 
$LANG['consumables'][21]="使用中"; 
$LANG['consumables'][22]="用過的"; 
$LANG['consumables'][23]="狀態"; 
$LANG['consumables'][26]="使用日期"; 
$LANG['consumables'][31]="給予"; 
$LANG['consumables'][32]="授予"; 
$LANG['consumables'][35]="已使用消耗品"; 
$LANG['consumables'][36]="儲蓄地點"; 
$LANG['consumables'][37]="回到目錄"; 
$LANG['consumables'][38]="報警閾值"; 

$LANG['contract'][0]="合約已到期 自"; 
$LANG['contract'][1]="合約已提醒 自"; 

$LANG['crontask'][0]="自動執行"; 
$LANG['crontask'][2]="發送墨盒警報"; 
$LANG['crontask'][3]="發送消耗品警報"; 
$LANG['crontask'][4]="過期授權發送警報"; 
$LANG['crontask'][5]="發送合約警報"; 
$LANG['crontask'][6]="發送會計和管理資訊警報"; 
$LANG['crontask'][7]="清除舊的日誌"; 
$LANG['crontask'][8]="資料庫最佳化"; 
$LANG['crontask'][9]="接收電子郵件（郵件伺服器）"; 
$LANG['crontask'][10]="檢查MySQL的replica"; 
$LANG['crontask'][11]="檢查更新"; 
$LANG['crontask'][12]="清除逾時的sessions"; 
$LANG['crontask'][13]="清除產成的圖片"; 
$LANG['crontask'][14]="問題單自動結案"; 
$LANG['crontask'][15]="未解決的問題單"; 
$LANG['crontask'][16]="自動操作的服務水平協議"; 
$LANG['crontask'][17]="監測自動執行"; 
$LANG['crontask'][18]="產生滿意度調查"; 
$LANG['crontask'][31]="已停用"; 
$LANG['crontask'][32]="已排定"; 
$LANG['crontask'][33]="執行中"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="執行模式"; 
$LANG['crontask'][37]="執行頻率"; 
$LANG['crontask'][38]="執行週期"; 
$LANG['crontask'][39]="待接收的電子郵件數量"; 
$LANG['crontask'][40]="最後執行"; 
$LANG['crontask'][41]="下次執行"; 
$LANG['crontask'][42]="儘快"; 
$LANG['crontask'][43]="未執行待決定"; 
$LANG['crontask'][44]="執行已完成，已處理一部分"; 
$LANG['crontask'][45]="執行已完成，已全部處理"; 
$LANG['crontask'][46]="執行已完成，不需要處理"; 
$LANG['crontask'][47]="最後運行清單"; 
$LANG['crontask'][48]="開始"; 
$LANG['crontask'][49]="後續自動執行發生錯誤,它需要人工介入."; 
$LANG['crontask'][50]="執行次數"; 
$LANG['crontask'][51]="最小時間"; 
$LANG['crontask'][52]="最大時間"; 
$LANG['crontask'][53]="平均時間"; 
$LANG['crontask'][55]="最小次數"; 
$LANG['crontask'][56]="最大次數"; 
$LANG['crontask'][57]="平均次數"; 
$LANG['crontask'][58]="總數"; 
$LANG['crontask'][59]="平均速度"; 
$LANG['crontask'][60]="系統鎖定"; 
$LANG['crontask'][61]="已停用插件"; 
$LANG['crontask'][62]="項目"; 

$LANG['devices'][0]="新增一個零組件"; 
$LANG['devices'][1]="硬碟"; 
$LANG['devices'][2]="圖形卡"; 
$LANG['devices'][3]="網卡"; 
$LANG['devices'][4]="處理器"; 
$LANG['devices'][5]="主機板"; 
$LANG['devices'][6]="記憶體"; 
$LANG['devices'][7]="音效卡"; 
$LANG['devices'][8]="系統板"; 
$LANG['devices'][9]="處理器"; 
$LANG['devices'][10]="網路卡"; 
$LANG['devices'][11]="記憶體"; 
$LANG['devices'][12]="硬碟驅動程式"; 
$LANG['devices'][13]="顯示卡"; 
$LANG['devices'][14]="音效卡"; 
$LANG['devices'][15]="案件"; 
$LANG['devices'][16]="電源供應器"; 
$LANG['devices'][17]="控制器"; 
$LANG['devices'][18]="驅動"; 
$LANG['devices'][19]="驅動程式"; 
$LANG['devices'][20]="控制器"; 
$LANG['devices'][21]="其他零組件"; 
$LANG['devices'][22]="機殼"; 
$LANG['devices'][23]="電源供應器"; 
$LANG['devices'][24]="按預設方式"; 
$LANG['devices'][25]="新增零組件"; 
$LANG['devices'][26]="刪除零組件"; 
$LANG['devices'][27]="其它設備"; 

$LANG['device_case'][0]="大小"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="寫入"; 
$LANG['device_drive'][1]="速度"; 

$LANG['device_hdd'][0]="轉速"; 
$LANG['device_hdd'][1]="高速緩存"; 
$LANG['device_hdd'][4]="容量"; 

$LANG['device_iface'][0]="流量"; 
$LANG['device_iface'][2]="MAC地址"; 

$LANG['device_moboard'][0]="晶片組"; 

$LANG['device_power'][0]="電源供應器"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="頻率"; 
$LANG['device_ram'][2]="大小"; 

$LANG['document'][1]="校驗 (SHA1)"; 
$LANG['document'][2]="文件"; 
$LANG['document'][3]="標題"; 
$LANG['document'][4]="MIME類型"; 
$LANG['document'][5]="和現有的文件關聯"; 
$LANG['document'][6]="新增一個檔案"; 
$LANG['document'][7]="文件類型"; 
$LANG['document'][8]="文件類型"; 
$LANG['document'][9]="擴展名"; 
$LANG['document'][10]="圖標"; 
$LANG['document'][11]="授權下載"; 
$LANG['document'][13]="沒有相關物件"; 
$LANG['document'][14]="相關物件"; 
$LANG['document'][15]="下載"; 
$LANG['document'][16]="新增一個文件"; 
$LANG['document'][17]="沒有相關文件"; 
$LANG['document'][18]="文件"; 
$LANG['document'][19]="關聯的項目"; 
$LANG['document'][20]="相關文件"; 
$LANG['document'][21]="相關文件"; 
$LANG['document'][22]="當前檔案"; 
$LANG['document'][23]="新增的檔案過大."; 
$LANG['document'][24]="檔案刪除成功"; 
$LANG['document'][25]="刪除檔案失敗"; 
$LANG['document'][26]="檔案是有效。 上載成功。"; 
$LANG['document'][27]="潛在的上傳攻擊。 或者，太大文件。 移動暫存檔失敗。"; 
$LANG['document'][28]="沒有指定檔案."; 
$LANG['document'][29]="創建目錄失敗"; 
$LANG['document'][30]="驗證您有正確權限"; 
$LANG['document'][31]="目錄為檔案不存在"; 
$LANG['document'][32]="未經授權檔案類型"; 
$LANG['document'][33]="網頁連結"; 
$LANG['document'][34]="創建目錄"; 
$LANG['document'][35]="上載目錄不存在"; 
$LANG['document'][36]="使用FTP安裝檔案"; 
$LANG['document'][37]="沒有有效有效"; 
$LANG['document'][38]="沒發現檔案"; 
$LANG['document'][39]="檔案移動成功"; 
$LANG['document'][40]="檔案移動發生了錯誤"; 
$LANG['document'][41]="檔案拷貝成功"; 
$LANG['document'][42]="新增由"; 
$LANG['document'][43]="未知的檔案"; 
$LANG['document'][44]="無效的檔名"; 
$LANG['document'][45]="對這個檔案沒有存取權限"; 
$LANG['document'][46]="傳檔失敗 (可能檔案過大)"; 
$LANG['document'][48]="該檔名的一個文件已被附加到（另一個）記錄"; 
$LANG['document'][49]="文件被改變（不正確的校驗）"; 

$LANG['dropdown'][1]="位置"; 
$LANG['dropdown'][2]="製造商"; 
$LANG['dropdown'][3]="問題單的類別"; 
$LANG['dropdown'][4]="作業類別"; 
$LANG['dropdown'][5]="解決方案類型"; 
$LANG['dropdown'][6]="請求來源"; 
$LANG['dropdown'][7]="解決方案模板"; 
$LANG['dropdown'][8]="電腦類型"; 
$LANG['dropdown'][9]="網路設備類型"; 
$LANG['dropdown'][10]="印表機類型"; 
$LANG['dropdown'][11]="顯示器類型"; 
$LANG['dropdown'][12]="設備類型"; 
$LANG['dropdown'][13]="電話類型"; 
$LANG['dropdown'][14]="授權類型"; 
$LANG['dropdown'][15]="聯絡人類型"; 
$LANG['dropdown'][16]="界面類型"; 
$LANG['dropdown'][17]="案件類型"; 
$LANG['dropdown'][18]="電話類型辭典"; 
$LANG['dropdown'][19]="檔案系統"; 
$LANG['dropdown'][20]="電腦型號"; 
$LANG['dropdown'][21]="網路模型"; 
$LANG['dropdown'][22]="印表機型號"; 
$LANG['dropdown'][23]="顯示器型號"; 
$LANG['dropdown'][24]="設備型號"; 
$LANG['dropdown'][25]="電話型號"; 
$LANG['dropdown'][26]="文件標題"; 
$LANG['dropdown'][27]="知識庫類別"; 
$LANG['dropdown'][28]="操作系統"; 
$LANG['dropdown'][29]="作業系統的版本"; 
$LANG['dropdown'][30]="Service Packs"; 
$LANG['dropdown'][31]="更新來源"; 
$LANG['dropdown'][32]="網路界面"; 
$LANG['dropdown'][33]="分位"; 
$LANG['dropdown'][34]="網域"; 

$LANG['entity'][0]="實體"; 
$LANG['entity'][2]="實體根目錄"; 
$LANG['entity'][6]="自動使用者指派分配"; 
$LANG['entity'][7]="樹狀結構"; 
$LANG['entity'][8]="依實體"; 
$LANG['entity'][9]="從屬實體"; 
$LANG['entity'][10]="選擇所需的實體"; 
$LANG['entity'][11]="顯示實體及從屬實體"; 
$LANG['entity'][12]="實體以LDAP目錄資料屬性表示"; 
$LANG['entity'][13]="實體識別TAG"; 
$LANG['entity'][14]="進階訊息"; 
$LANG['entity'][15]="LDAP目錄中的一個實體"; 
$LANG['entity'][16]="搜尋篩選(如需要)"; 
$LANG['entity'][17]="自動結束設定"; 
$LANG['entity'][18]="問題單自動結案,自"; 
$LANG['entity'][19]="設定滿意度調查"; 
$LANG['entity'][20]="創建的調查分析"; 
$LANG['entity'][21]="觸發調查率"; 
$LANG['entity'][22]="讓問題單關閉,於"; 
$LANG['entity'][23]="實體分配值的一般規則"; 
$LANG['entity'][24]="LDAP目錄搜索使用者界面中使用的值"; 
$LANG['entity'][25]="LDAP篩選 關聯至物件（如需要）"; 
$LANG['entity'][26]="這些參數作為一般規則執行實體指派"; 
$LANG['entity'][27]="郵件域代理實體"; 
$LANG['entity'][28]="問題單的預設類型"; 

$LANG['event'][0]="來源"; 
$LANG['event'][2]="服務"; 
$LANG['event'][3]="等級"; 
$LANG['event'][4]="訊息"; 
$LANG['event'][18]="領域"; 
$LANG['event'][19]="更新"; 
$LANG['event'][20]="沒有歷史"; 

$LANG['financial'][1]="合約"; 
$LANG['financial'][2]="終身"; 
$LANG['financial'][3]="會計和管理資訊"; 
$LANG['financial'][4]="數字"; 
$LANG['financial'][5]="花費"; 
$LANG['financial'][6]="合約類型"; 
$LANG['financial'][7]="保固資訊"; 
$LANG['financial'][8]="最初的合同期限"; 
$LANG['financial'][9]="年"; 
$LANG['financial'][10]="通知"; 
$LANG['financial'][11]="發票週期"; 
$LANG['financial'][13]="統一編號"; 
$LANG['financial'][14]="購買日期"; 
$LANG['financial'][15]="保固期"; 
$LANG['financial'][16]="保固訊息"; 
$LANG['financial'][18]="序號"; 
$LANG['financial'][19]="送貨單"; 
$LANG['financial'][20]="固定數字"; 
$LANG['financial'][21]="價值"; 
$LANG['financial'][22]="分期償還類型"; 
$LANG['financial'][23]="分期償還期間"; 
$LANG['financial'][24]="新增聯絡人…"; 
$LANG['financial'][25]="新增供應商..."; 
$LANG['financial'][26]="供應商"; 
$LANG['financial'][27]="交貨日期"; 
$LANG['financial'][28]="訂購日期"; 
$LANG['financial'][29]="保固起始日期"; 
$LANG['financial'][30]="傳真"; 
$LANG['financial'][33]="新增聯絡人"; 
$LANG['financial'][36]="新增一個合約"; 
$LANG['financial'][40]="沒有相關聯絡人"; 
$LANG['financial'][41]="相關聯絡人"; 
$LANG['financial'][42]="商務"; 
$LANG['financial'][43]="工程師"; 
$LANG['financial'][44]="地址"; 
$LANG['financial'][45]="網站"; 
$LANG['financial'][46]="相關聯絡人"; 
$LANG['financial'][47]="線性"; 
$LANG['financial'][48]="遞減"; 
$LANG['financial'][50]="借出"; 
$LANG['financial'][51]="租賃"; 
$LANG['financial'][52]="租約"; 
$LANG['financial'][53]="保險"; 
$LANG['financial'][54]="硬體支援"; 
$LANG['financial'][55]="軟體支援"; 
$LANG['financial'][56]="服務商"; 
$LANG['financial'][57]="月"; 
$LANG['financial'][58]="沒有相關合約"; 
$LANG['financial'][59]="維護支援時間"; 
$LANG['financial'][60]="週一至週五"; 
$LANG['financial'][61]="星期六"; 
$LANG['financial'][62]="星期天和例假日"; 
$LANG['financial'][63]="相關合約"; 
$LANG['financial'][64]="相關供應商"; 
$LANG['financial'][65]="相關供應商"; 
$LANG['financial'][66]="同合約關聯在一起"; 
$LANG['financial'][67]="沒有相關供應商"; 
$LANG['financial'][68]="啟用會計和管理訊息"; 
$LANG['financial'][69]="合約週期性"; 
$LANG['financial'][76]="開始日期"; 
$LANG['financial'][77]="分期償還係數"; 
$LANG['financial'][78]="停止保固後殘值"; 
$LANG['financial'][79]="第三方類型"; 
$LANG['financial'][80]="保固到期日"; 
$LANG['financial'][81]="帳戶淨值"; 
$LANG['financial'][82]="發票號碼"; 
$LANG['financial'][83]="項目最大值(0=無限的)"; 
$LANG['financial'][84]="你應該新增這個類型的項目，會計和管理資訊只有一個型號項目。"; 
$LANG['financial'][85]="未發現請求的項目"; 
$LANG['financial'][86]="結束的合約"; 
$LANG['financial'][87]="預算"; 
$LANG['financial'][88]="到期："; 
$LANG['financial'][89]="總成本 (價值+追蹤成本)"; 
$LANG['financial'][90]="月 總成本"; 
$LANG['financial'][91]="總成本"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="已到期的合約(30天內)"; 
$LANG['financial'][94]="小於7天到期的合約"; 
$LANG['financial'][95]="小於30天到期的合約"; 
$LANG['financial'][96]="通知(小於7天到期的合約)"; 
$LANG['financial'][97]="通知(小於30天到期的合約)"; 
$LANG['financial'][98]="到期日"; 
$LANG['financial'][99]="到期日+通知"; 
$LANG['financial'][100]="郵遞區號"; 
$LANG['financial'][101]="城市"; 
$LANG['financial'][102]="省 / 洲"; 
$LANG['financial'][103]="國家"; 
$LANG['financial'][104]="關聯項目"; 
$LANG['financial'][105]="默認"; 
$LANG['financial'][106]="表達"; 
$LANG['financial'][107]="更新"; 
$LANG['financial'][108]="總計花費預算"; 
$LANG['financial'][109]="預算總餘額"; 
$LANG['financial'][110]="預算"; 
$LANG['financial'][111]="自動填寫日期"; 
$LANG['financial'][112]="填寫移轉狀態"; 
$LANG['financial'][113]="沒有自動填寫"; 
$LANG['financial'][114]="最後盤點日期"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="小時(s)"; 
$LANG['gmt'][2]="小時"; 

$LANG['group'][0]="在問題單可見"; 
$LANG['group'][1]="可通知"; 
$LANG['group'][2]="可包含"; 
$LANG['group'][3]="子群組"; 

$LANG['help'][1]="矩陣演算優先"; 
$LANG['help'][2]="主要"; 
$LANG['help'][3]="非常高"; 
$LANG['help'][4]="高"; 
$LANG['help'][5]="中"; 
$LANG['help'][6]="低"; 
$LANG['help'][7]="非常低"; 
$LANG['help'][8]="通知我關於採取的執行"; 
$LANG['help'][14]="發送訊息"; 
$LANG['help'][18]="您的問題單已登記,正在進行處理。."; 
$LANG['help'][19]="感謝您使用我們的自動服務台系統."; 
$LANG['help'][22]="搜尋您電腦的 ID"; 
$LANG['help'][23]="輸入的第一個字母(使用者、項目名稱或者序號)"; 
$LANG['help'][24]="硬體類型"; 
$LANG['help'][25]="電腦"; 
$LANG['help'][26]="網絡設備"; 
$LANG['help'][27]="印表機"; 
$LANG['help'][28]="顯示器"; 
$LANG['help'][29]="設備"; 
$LANG['help'][30]="通用"; 
$LANG['help'][31]="軟體"; // Singular
$LANG['help'][35]="電話"; 
$LANG['help'][40]="問題單為沒有標題,請重試."; 
$LANG['help'][41]="問題單為沒有類型,請重試."; 
$LANG['help'][42]="非常高"; 
$LANG['help'][43]="高"; 
$LANG['help'][44]="中"; 
$LANG['help'][45]="低"; 
$LANG['help'][46]="非常低"; 
$LANG['help'][47]="非常高"; 
$LANG['help'][48]="高"; 
$LANG['help'][49]="中"; 
$LANG['help'][50]="低"; 
$LANG['help'][51]="非常低"; 

$LANG['install'][0]="GLPI安裝或更新"; 
$LANG['install'][1]="選擇 '安裝' 以完整安裝新的GLPI."; 
$LANG['install'][2]="選擇 '更新' 以更新您的GLPI版本"; 
$LANG['install'][3]="安裝"; 
$LANG['install'][4]="更新"; 
$LANG['install'][5]="檢查您執行GPLI環境的相容性"; 
$LANG['install'][6]="測試完成"; 
$LANG['install'][7]="發生"; 
$LANG['install'][8]="測試PHP分析器"; 
$LANG['install'][9]="你必需安裝新的PHP5."; 
$LANG['install'][10]="GLPI 與zend.ze1_compatibility_mode = On選項不相容."; 
$LANG['install'][11]="PHP 是最新版本 5.x - 漂亮 !"; 
$LANG['install'][12]="電文測試"; 
$LANG['install'][13]="您的PHP解析器沒有安裝對電文(Session)的支援!"; 
$LANG['install'][14]="Session的支援是可用的-漂亮!"; 
$LANG['install'][15]="檢查Session的支援在您的php.ini已啟用"; 
$LANG['install'][16]="測試暫存檔寫入的權限"; 
$LANG['install'][17]="文件無法創建。"; 
$LANG['install'][18]="非官方的翻譯也可"; 
$LANG['install'][19]="文件創建了但不能被刪除。"; 
$LANG['install'][20]="文件和檔案已被創建並刪除 - 完成 !"; 
$LANG['install'][21]="測試文件檔寫入的權限"; 
$LANG['install'][22]="文件已被創建 - 完成 !"; 
$LANG['install'][23]="測試設定檔寫入權限"; 
$LANG['install'][24]="初始化資料庫"; 
$LANG['install'][25]="繼續？"; 
$LANG['install'][26]="繼續"; 
$LANG['install'][27]="重試"; 
$LANG['install'][28]="資料庫連接設定"; 
$LANG['install'][29]="資料庫連接參數"; 
$LANG['install'][30]="Mysql 主機"; 
$LANG['install'][31]="Mysql 使用者"; 
$LANG['install'][32]="Mysql 密碼"; 
$LANG['install'][34]="測試接資料庫"; 
$LANG['install'][35]="無法連接在資料庫"; 
$LANG['install'][36]="伺服器回答了"; 
$LANG['install'][37]="伺服器或使用者欄位未填寫"; 
$LANG['install'][38]="請選項一個資料庫："; 
$LANG['install'][39]="創建一個新的資料庫或是使用一個已經存在的資料庫:"; 
$LANG['install'][40]="請選擇資料庫更新："; 
$LANG['install'][41]="無法使用資料庫："; 
$LANG['install'][43]="OK-資料庫初始化了"; 
$LANG['install'][47]="無法修改資料庫設定文件"; 
$LANG['install'][48]="創建資料庫錯誤!"; 
$LANG['install'][49]="您沒有選擇一個資料庫!"; 
$LANG['install'][50]="測試Session檔寫入的權限"; 
$LANG['install'][52]="測試Cron檔寫入的權限"; 
$LANG['install'][53]="測試寫入 log"; 
$LANG['install'][55]="安裝完成"; 
$LANG['install'][57]="預設 logins / passwords 是:"; 
$LANG['install'][58]="glpi/glpi為管理員帳戶"; 
$LANG['install'][59]="tech/tech為工程師帳戶"; 
$LANG['install'][60]="normal為正常帳戶"; 
$LANG['install'][61]="post-only/post-only為postonly帳戶"; 
$LANG['install'][62]="您最好在第一筆資料建立入資料庫前能刪除或修改這些帳戶。"; 
$LANG['install'][64]="使用GLPI"; 
$LANG['install'][65]="magic_quotes_sybase延申測試"; 
$LANG['install'][66]="GLPI不與magic_quotes_sybase選項一起使用; 請設置它再試"; 
$LANG['install'][67]="magic_quotes_sybase選項未啟用在您的服務器-漂亮!"; 
$LANG['install'][68]="測試session自動啟動"; 
$LANG['install'][69]="session.auto_start 已啟動. 查看 .htaccess 檔以獲得更多訊息,該檔案在 GLPI 根目錄."; 
$LANG['install'][70]="不可能創建資料庫連接文件，在文件請驗證權限"; 
$LANG['install'][71]="Mysql擴展名測試。"; 
$LANG['install'][72]="您必須安裝PHP的MySQL延伸套件。"; 
$LANG['install'][73]="好-作用mysql_query ()存在-漂亮!"; 
$LANG['install'][74]="測試是否使用Session_use_trans_sid"; 
$LANG['install'][75]="您在您的php.ini必須停用Session_use_trans_id選項"; 
$LANG['install'][76]="好-會議運作(沒有問題與trans_id) -漂亮!"; 
$LANG['install'][77]="步"; 
$LANG['install'][81]="安裝的起點"; 
$LANG['install'][82]="已建立資料庫"; 
$LANG['install'][85]="功能被發現了-漂亮!"; 
$LANG['install'][86]="分配記憶體測試"; 
$LANG['install'][87]="分配記憶體："; 
$LANG['install'][88]="GPLI至少需要 64MB."; 
$LANG['install'][89]="漂亮!"; 
$LANG['install'][90]="新增memory_limit參量的嘗試在php.ini文件。"; 
$LANG['install'][91]="已分配記憶體 > 64M"; 
$LANG['install'][92]="使用許可"; 
$LANG['install'][93]="我已讀完並且接受以上預設的使用許可的條件。"; 
$LANG['install'][94]="我已讀完代不接受被寫上面使用許可的條件"; 
$LANG['install'][95]="記憶體無限"; 
$LANG['install'][96]="記憶體無限"; 
$LANG['install'][97]="檢查目錄的權限:"; 
$LANG['install'][99]="檢查暫存檔寫入的權限"; 
$LANG['install'][100]="該目錄無法被建立."; 
$LANG['install'][101]="該目錄已備建立,但無法移除."; 
$LANG['install'][102]="測試JSON的功能"; 
$LANG['install'][103]="GLPI 無法在 沒有json_encode和json_decode功能下正常運行."; 
$LANG['install'][104]="mbstring擴展測試"; 
$LANG['install'][105]="您的PHP解析器沒有安裝Mbstring功能"; 
$LANG['install'][106]="檢查圖檔的寫入權限"; 

$LANG['job'][1]="事件"; 
$LANG['job'][2]="依"; 
$LANG['job'][3]="技術人員"; 
$LANG['job'][4]="請求者"; 
$LANG['job'][5]="分配給"; 
$LANG['job'][6]="技術人員"; 
$LANG['job'][7]="作業"; 
$LANG['job'][8]="進行中的問題單"; 
$LANG['job'][9]="後續"; 
$LANG['job'][10]="最後的問題單"; 
$LANG['job'][11]="問題描述/處理情形"; 
$LANG['job'][12]="這個問題單沒有後續追蹤。"; 
$LANG['job'][13]="新增問題單"; 
$LANG['job'][14]="開始"; 
$LANG['job'][15]="已解決"; 
$LANG['job'][16]="結案"; 
$LANG['job'][17]="延遲"; 
$LANG['job'][18]="請求者"; 
$LANG['job'][19]="郵件後續追蹤"; 
$LANG['job'][20]="總期間"; 
$LANG['job'][21]="最近的問題"; 
$LANG['job'][22]="分(s)"; 
$LANG['job'][23]="搜索解決方案"; 
$LANG['job'][24]="使用為一種解決方案"; 
$LANG['job'][25]="保存並新增到知識庫"; 
$LANG['job'][26]="您已被重定向，因為你無法再使用此問題單"; 
$LANG['job'][27]="新增一個角色"; 
$LANG['job'][28]="預設模板"; 
$LANG['job'][29]="新增後續追蹤"; 
$LANG['job'][30]="新增一個作業"; 
$LANG['job'][31]="期間"; 
$LANG['job'][32]="無"; 
$LANG['job'][33]="空的描述"; 
$LANG['job'][34]="規劃後續追蹤"; 
$LANG['job'][35]="規劃中"; 
$LANG['job'][36]="問題單進度或最近已解決項目。"; 
$LANG['job'][37]="總結"; 
$LANG['job'][38]="問題單"; 
$LANG['job'][40]="時間成本"; 
$LANG['job'][41]="固定成本"; 
$LANG['job'][42]="物質費用"; 
$LANG['job'][43]="總成本"; 
$LANG['job'][44]="請求來源"; 
$LANG['job'][45]="後續來源"; 
$LANG['job'][46]="問題單已被建立為一個實體"; 
$LANG['job'][47]="成本"; 
$LANG['job'][48]="解決方案的類型"; 
$LANG['job'][49]="新作業"; 
$LANG['job'][50]="沒有作業給這張問題單"; 
$LANG['job'][51]="核准該解決方案"; 
$LANG['job'][52]="更新作業"; 
$LANG['job'][53]="刪除作業"; 
$LANG['job'][54]="如果沒有回覆，問題單將自動結案"; 
$LANG['job'][55]="已連結的問題單"; 
$LANG['job'][56]="連結問題單"; 
$LANG['job'][57]="重複的問題單"; 
$LANG['job'][58]="問題單模板"; 
$LANG['job'][59]="問題單模板"; 
$LANG['job'][60]="隱藏欄位"; 
$LANG['job'][61]="預定欄位"; 
$LANG['job'][62]="必填欄位"; 
$LANG['job'][63]="隱藏欄位"; 
$LANG['job'][64]="預定欄位"; 
$LANG['job'][65]="必填欄位"; 
$LANG['job'][66]="請求模板"; 
$LANG['job'][67]="事件模板"; 
$LANG['job'][68]="必填欄位沒有填寫。請更正："; 
$LANG['job'][69]="與我有關的問題單"; 
$LANG['job'][70]="可見事件"; 
$LANG['job'][71]="可見請求"; 
$LANG['job'][72]="可見問題"; 

$LANG['joblist'][0]="狀態"; 
$LANG['joblist'][1]="只有我的"; 
$LANG['joblist'][2]="優先權"; 
$LANG['joblist'][3]="個人 + 群組(s)"; 
$LANG['joblist'][4]="已分配"; 
$LANG['joblist'][5]="建立問題單"; 
$LANG['joblist'][6]="描述"; 
$LANG['joblist'][7]="為此項目新增問題單…"; 
$LANG['joblist'][8]="沒有發現問題單"; 
$LANG['joblist'][9]="新增"; 
$LANG['joblist'][10]="結案(已解決)"; 
$LANG['joblist'][11]="開始在"; 
$LANG['joblist'][12]="關閉在"; 
$LANG['joblist'][13]="需處理的問題單"; 
$LANG['joblist'][14]="解決關於"; 
$LANG['joblist'][15]="擱置"; 
$LANG['joblist'][16]="沒有問題單在進行."; 
$LANG['joblist'][17]="結案(未解決)"; 
$LANG['joblist'][18]="處理中(已分配)"; 
$LANG['joblist'][19]="處理中(已計劃)"; 
$LANG['joblist'][20]="沒有發現問題"; 
$LANG['joblist'][21]="處理中"; 
$LANG['joblist'][25]="問題單連結的項目"; 
$LANG['joblist'][26]="待決定"; 
$LANG['joblist'][27]="郵件追蹤"; 
$LANG['joblist'][28]="問題單的連結項目"; 
$LANG['joblist'][29]="緊急"; 
$LANG['joblist'][30]="影響"; 
$LANG['joblist'][31]="連結項目的問題"; 
$LANG['joblist'][32]="已解決"; 
$LANG['joblist'][33]="結案"; 
$LANG['joblist'][34]="未解決"; 
$LANG['joblist'][35]="未結案"; 
$LANG['joblist'][36]="資料庫的狀態值"; 

$LANG['jobrecurrent'][1]="經常性問題單"; 
$LANG['jobrecurrent'][2]="初步創建"; 
$LANG['jobrecurrent'][3]="創建下一步"; 
$LANG['jobrecurrent'][4]="無效讀頻率。它必須大於初建值。"; 

$LANG['jobresolution'][1]="解決"; 
$LANG['jobresolution'][2]="解決方案"; 
$LANG['jobresolution'][3]="核准解決方案"; 
$LANG['jobresolution'][4]="拒絕解決方案"; 
$LANG['jobresolution'][5]="如果你拒絕該解決方案，您必須明確說明原因"; 
$LANG['jobresolution'][6]="解決方案模板"; 

$LANG['knowbase'][1]="常見問題解答"; 
$LANG['knowbase'][2]="未公佈的文章"; 
$LANG['knowbase'][3]="未公佈"; 
$LANG['knowbase'][5]="將此項目放入常見問題解答"; 
$LANG['knowbase'][6]="為項目選項一個類別："; 
$LANG['knowbase'][7]="從常見問答刪除這個項目"; 
$LANG['knowbase'][8]="編輯這個項目"; 
$LANG['knowbase'][9]="刪除這個項目"; 
$LANG['knowbase'][10]="這項目是公眾常見問答的一部分"; 
$LANG['knowbase'][11]="這項目不作為公眾常見問答的部分"; 
$LANG['knowbase'][13]="類別名稱"; 
$LANG['knowbase'][14]="標題"; 
$LANG['knowbase'][15]="內容"; 
$LANG['knowbase'][24]="查看FAQ"; 
$LANG['knowbase'][26]="查看"; 
$LANG['knowbase'][27]="開"; 
$LANG['knowbase'][29]="近來的輸入"; 
$LANG['knowbase'][30]="常問的問題"; 

$LANG['ldap'][0]="由 LDAP目錄整批導入使用者"; 
$LANG['ldap'][1]="使用者同步已完成導入"; 
$LANG['ldap'][2]="導入新使用者"; 
$LANG['ldap'][3]="沒有使用者需導入"; 
$LANG['ldap'][4]="選擇LDAP目錄"; 
$LANG['ldap'][5]="請選擇LDAP目錄以導入使用者"; 
$LANG['ldap'][6]="無法連結 LDAP 目錄"; 
$LANG['ldap'][7]="沒有 LDAP 目錄設定於 GLPI"; 
$LANG['ldap'][8]="警告：請求超出目錄的限制。只有部份結果。"; 
$LANG['ldap'][9]="測試連線至 LDAP 目錄"; 
$LANG['ldap'][10]="成功導入"; 
$LANG['ldap'][11]="強制同步"; 
$LANG['ldap'][12]="同步"; 
$LANG['ldap'][13]="在 LDAP"; 
$LANG['ldap'][14]="在 GLPI"; 
$LANG['ldap'][15]="同步"; 
$LANG['ldap'][16]="預設"; 
$LANG['ldap'][17]="Active 目錄"; 
$LANG['ldap'][18]="條列 LDAP replica"; 
$LANG['ldap'][19]="Replicate"; 
$LANG['ldap'][20]="新增一個LDAP replica"; 
$LANG['ldap'][21]="主伺服器"; 
$LANG['ldap'][22]="Replicate(s)"; 
$LANG['ldap'][23]="由 LDAP 目錄整批導入群組"; 
$LANG['ldap'][24]="導入新群組"; 
$LANG['ldap'][25]="沒有群組需要導入"; 
$LANG['ldap'][26]="使用者的DN"; 
$LANG['ldap'][27]="目標實體"; 
$LANG['ldap'][30]="LDAP 別名應如何處理"; 
$LANG['ldap'][31]="從來沒有解除引用(預設)"; 
$LANG['ldap'][32]="始終解除引用"; 
$LANG['ldap'][33]="在搜查過程中取消引用 (當 定位 時除外)"; 
$LANG['ldap'][34]="定位時解除引用 (當搜尋時除外)"; 
$LANG['ldap'][35]="導入使用者"; 
$LANG['ldap'][36]="沒有目錄關聯的實體：不能搜索"; 
$LANG['ldap'][38]="使用者搜索標準"; 
$LANG['ldap'][39]="進階"; 
$LANG['ldap'][40]="簡易"; 
$LANG['ldap'][41]="要更改"; 
$LANG['ldap'][42]="沒有已選擇的目錄"; 
$LANG['ldap'][43]="沒有使用者需進行同步"; 
$LANG['ldap'][44]="預設伺服器"; 
$LANG['ldap'][45]="當使用者從 LDAP目錄中刪除後執行"; 
$LANG['ldap'][46]="撤銷認證和群組（動態）"; 
$LANG['ldap'][47]="放進垃圾桶"; 
$LANG['ldap'][48]="已刪除LDAP目錄中的使用者"; 
$LANG['ldap'][49]="查看使用者新增自"; 
$LANG['ldap'][50]="查看使用者更新，自"; 
$LANG['ldap'][54]="啟用日期篩選"; 
$LANG['ldap'][55]="停用日期篩選"; 
$LANG['ldap'][56]="週"; 

$LANG['links'][1]="連結或文件名"; 
$LANG['links'][4]="硬體類型聯合"; 
$LANG['links'][6]="有效標記"; 
$LANG['links'][7]="沒有連結定義"; 
$LANG['links'][9]="文件內容"; 

$LANG['log'][1]="系統"; 
$LANG['log'][16]="計劃"; 
$LANG['log'][18]="零件"; 
$LANG['log'][20]="項目新增了"; 
$LANG['log'][21]="更新項目"; 
$LANG['log'][22]="刪除項目"; 
$LANG['log'][23]="恢復項目"; 
$LANG['log'][24]="清除項目"; 
$LANG['log'][26]="中斷這項目"; 
$LANG['log'][27]="項目連接"; 
$LANG['log'][28]="更新零件"; 
$LANG['log'][29]="核准/拒絕 這些解決方案"; 
$LANG['log'][30]="關聯類型"; 
$LANG['log'][31]="刪除類型"; 
$LANG['log'][32]="新增一個項目連結"; 
$LANG['log'][33]="刪除項目的連結"; 
$LANG['log'][34]="新增一個供應商連結"; 
$LANG['log'][35]="刪除一個供應商連結"; 
$LANG['log'][40]="IP連接"; 
$LANG['log'][41]="連接發生了故障"; 
$LANG['log'][42]="預借"; 
$LANG['log'][44]="標題"; 
$LANG['log'][45]="成功"; 
$LANG['log'][46]="發生了故障"; 
$LANG['log'][48]="新增使用者到群組"; 
$LANG['log'][49]="刪除組的使用者"; 
$LANG['log'][50]="修改使用者群組"; 
$LANG['log'][51]="新增隱藏的欄位"; 
$LANG['log'][52]="刪除一個隱藏欄位"; 
$LANG['log'][55]="連接"; 
$LANG['log'][56]="新增強制的欄位"; 
$LANG['log'][57]="刪除一個強制性的欄位"; 
$LANG['log'][58]="新增預定義的欄位"; 
$LANG['log'][59]="自動執行"; 
$LANG['log'][60]="這個項目使用單一管理"; 
$LANG['log'][61]="項目新增使用者"; 
$LANG['log'][62]="完整移除此使用者"; 
$LANG['log'][63]="刪除預定義的欄位"; 
$LANG['log'][64]="修改評論"; 
$LANG['log'][65]="規則"; 
$LANG['log'][66]="安全"; 
$LANG['log'][67]="刪除目標"; 
$LANG['log'][68]="新增一個目標"; 
$LANG['log'][70]="完成新增網路port"; 
$LANG['log'][71]="完成新增伺服器網路port"; 
$LANG['log'][73]="完成刪除網路port"; 
$LANG['log'][74]="完成刪除伺服器網路port"; 
$LANG['log'][75]="移除網路端口"; 
$LANG['log'][77]="分配給 VLAN的網絡端口"; 
$LANG['log'][78]="分配給 VLAN的端口數"; 
$LANG['log'][79]="未分配到一個 VLAN的網絡端口"; 
$LANG['log'][80]="VLAN的未分配數個網絡端口"; 
$LANG['log'][82]="加入版本"; 
$LANG['log'][83]="修改版本"; 
$LANG['log'][84]="刪除版本"; 
$LANG['log'][85]="新增授權"; 
$LANG['log'][86]="修改授權"; 
$LANG['log'][87]="刪除授權"; 
$LANG['log'][88]="新增墨水夾"; 
$LANG['log'][89]="加入消耗品"; 
$LANG['log'][90]="排除墨水夾"; 
$LANG['log'][91]="排除的耗材"; 
$LANG['log'][92]="恢復墨水夾"; 
$LANG['log'][93]="從耗材中恢復"; 
$LANG['log'][94]="墨水夾更新"; 
$LANG['log'][95]="墨水夾安裝"; 
$LANG['log'][96]="墨水夾移除"; 
$LANG['log'][97]="該使用者耗材用盡"; 
$LANG['log'][98]="新增一個項目"; 
$LANG['log'][99]="修改的項目"; 
$LANG['log'][100]="刪除一個項目"; 
$LANG['log'][110]="軟體安裝"; 
$LANG['log'][111]="軟件移除"; 
$LANG['log'][112]="移除數個軟體"; 
$LANG['log'][113]="安裝數個軟體"; 
$LANG['log'][114]="移除多台電腦上的軟體"; 
$LANG['log'][115]="改變安裝的軟體版本"; 
$LANG['log'][116]="結合電腦和授權"; 
$LANG['log'][117]="更改數台電腦的授權"; 
$LANG['log'][118]="將多台電腦授權分離"; 
$LANG['log'][120]="刪除問題單之間的連結"; 
$LANG['log'][122]="刪除問題單的參與者"; 
$LANG['log'][123]="嘗試添加一個已經存在的項目"; 

$LANG['login'][0]="最後登入"; 
$LANG['login'][1]="再次登錄"; 
$LANG['login'][2]="LDAP"; 
$LANG['login'][3]="電子郵件伺服器"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="拒絕存取"; 
$LANG['login'][6]="使用者名稱"; 
$LANG['login'][7]="密碼"; 
$LANG['login'][8]="空白的登錄或密碼"; 
$LANG['login'][9]="尚未身份驗證"; 
$LANG['login'][10]="身份驗證"; 
$LANG['login'][11]="使用者無權連接GLPI"; 
$LANG['login'][12]="錯誤的帳號/密碼"; 
$LANG['login'][13]="密碼為空白"; 
$LANG['login'][14]="無此使用者"; 
$LANG['login'][15]="無法找到使用者或發現多個使用者"; 
$LANG['login'][17]="其他身份驗證方法"; 
$LANG['login'][18]="基於GLPI本身"; 
$LANG['login'][19]="其它身份驗證發送的HTTP請求"; 
$LANG['login'][20]="你無法對這個程式進行存取,您的帳戶可能被停用或刪除"; 
$LANG['login'][21]="測試連線至電子郵件伺服器"; 
$LANG['login'][22]="測試成功"; 
$LANG['login'][23]="測試失敗"; 
$LANG['login'][24]="最後登入時間"; 
$LANG['login'][25]="無法正常連線"; 
$LANG['login'][26]="您必需啟用瀏覽器 JavaScript 功能"; 
$LANG['login'][27]="您必要同意這個程式使用 cookies"; 
$LANG['login'][29]="上次同步"; 
$LANG['login'][30]="變更驗證方式"; 
$LANG['login'][31]="在目錄認證"; 
$LANG['login'][32]="在 GLPI 資料庫認證"; 
$LANG['login'][33]="在電子郵件伺服器認證"; 

$LANG['mailgate'][0]="郵件接收器"; 
$LANG['mailgate'][1]="電子郵件被拒絕"; 
$LANG['mailgate'][2]="現在取得e-Mail問題單"; 
$LANG['mailgate'][3]="已收到可讀的信件數"; 
$LANG['mailgate'][4]="mbstring 延申功能未發現. 警告使用的字符集."; 
$LANG['mailgate'][5]="無效的附件檔"; 
$LANG['mailgate'][6]="附件檔太大"; 
$LANG['mailgate'][7]="接收郵件: 每個附件的最大值 (0 : 不可)"; 
$LANG['mailgate'][8]="沒有導入"; 
$LANG['mailgate'][9]="您的電子郵件無法處理。\n如果問題仍然存在，請聯繫管理員"; 
$LANG['mailgate'][10]="電子郵件被拒絕"; 
$LANG['mailgate'][11]="電子郵件導入的處理"; 
$LANG['mailgate'][12]="無法影響實體的電子郵件"; 
$LANG['mailgate'][13]="回絕原因"; 
$LANG['mailgate'][14]="沒有找到電子郵件, 無法導入"; 
$LANG['mailgate'][16]="回覆:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="=====================================================================]="; 
$LANG['mailing'][2]="通知的前綴"; 
$LANG['mailing'][3]="由GLPI自動生成"; 
$LANG['mailing'][4]="計劃更新"; 
$LANG['mailing'][5]="問題單的描述"; 
$LANG['mailing'][6]="CSS"; 
$LANG['mailing'][10]="新問題單的後續"; 
$LANG['mailing'][19]="新增預借"; 
$LANG['mailing'][23]="預借修改"; 
$LANG['mailing'][26]="新增文件 :"; 
$LANG['mailing'][29]="取消預借"; 
$LANG['mailing'][30]="問題單更新"; 
$LANG['mailing'][31]="這是測試電子郵件"; 
$LANG['mailing'][32]="郵件測試"; 
$LANG['mailing'][33]="墨水夾警報"; 
$LANG['mailing'][35]="消耗品種類到達報警閾值："; 
$LANG['mailing'][36]="消耗品警報"; 
$LANG['mailing'][37]="在通知時間導入的合約："; 
$LANG['mailing'][39]="合約警報"; 
$LANG['mailing'][40]="項目保修結束："; 
$LANG['mailing'][47]="寄送電子郵件發生錯誤"; 
$LANG['mailing'][51]="授權過期 :"; 
$LANG['mailing'][52]="發送警報"; 
$LANG['mailing'][54]="到期日"; 
$LANG['mailing'][100]="沒有被定義的類別"; 
$LANG['mailing'][104]="後續期間"; 
$LANG['mailing'][108]="事件"; 
$LANG['mailing'][109]="翻譯"; 
$LANG['mailing'][110]="無效的電子郵件"; 
$LANG['mailing'][111]="電子郵件地址"; 
$LANG['mailing'][112]="通知模型"; 
$LANG['mailing'][113]="通知模板"; 
$LANG['mailing'][114]="內容"; 
$LANG['mailing'][115]="電子郵件的主體"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="正文"; 
$LANG['mailing'][118]="電子郵件"; 
$LANG['mailing'][119]="發生"; 
$LANG['mailing'][120]="通知方法"; 
$LANG['mailing'][121]="收件人"; 
$LANG['mailing'][122]="作業已完成"; 
$LANG['mailing'][123]="已解決的問題單"; 
$LANG['mailing'][124]="新增一個新的翻譯"; 
$LANG['mailing'][125]="預設語系"; 
$LANG['mailing'][126]="模板翻譯"; 
$LANG['mailing'][127]="將問題單結案"; 
$LANG['mailing'][128]="新網頁保留空白的欄位"; 
$LANG['mailing'][129]="刪除問題單"; 
$LANG['mailing'][130]="寄件者"; 
$LANG['mailing'][131]="收件人"; 
$LANG['mailing'][132]="電子郵件標題"; 
$LANG['mailing'][133]="刪除電子郵件"; 
$LANG['mailing'][134]="後續更新中"; 
$LANG['mailing'][135]="後續刪除"; 
$LANG['mailing'][136]="預借過期"; 
$LANG['mailing'][137]="硬體使用者"; 
$LANG['mailing'][138]="可用的標籤列表"; 
$LANG['mailing'][139]="標籤"; 
$LANG['mailing'][140]="標籤"; 
$LANG['mailing'][141]="後續"; 
$LANG['mailing'][142]="作業"; 
$LANG['mailing'][144]="歷史"; 
$LANG['mailing'][145]="列出值"; 
$LANG['mailing'][146]="單一值"; 
$LANG['mailing'][147]="可能的值"; 

$LANG['Menu'][0]="電腦"; 
$LANG['Menu'][1]="網絡"; 
$LANG['Menu'][2]="印表機"; 
$LANG['Menu'][3]="顯示器"; 
$LANG['Menu'][4]="軟體"; // Plural
$LANG['Menu'][5]="固定資產追蹤"; 
$LANG['Menu'][6]="報告"; 
$LANG['Menu'][7]="問題"; 
$LANG['Menu'][8]="變更"; 
$LANG['Menu'][9]="LDAP目錄"; 
$LANG['Menu'][10]="郵件伺服器"; 
$LANG['Menu'][11]="設置"; 
$LANG['Menu'][12]="資料庫"; 
$LANG['Menu'][13]="統計"; 
$LANG['Menu'][14]="使用者"; 
$LANG['Menu'][15]="管理"; 
$LANG['Menu'][16]="設備"; 
$LANG['Menu'][17]="預借"; 
$LANG['Menu'][18]="工具"; 
$LANG['Menu'][19]="知識庫"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="墨水夾"; 
$LANG['Menu'][22]="聯絡人"; 
$LANG['Menu'][23]="供應廠商"; 
$LANG['Menu'][24]="會計和管理資訊"; 
$LANG['Menu'][25]="合約"; 
$LANG['Menu'][26]="管理"; 
$LANG['Menu'][27]="文件檔"; 
$LANG['Menu'][28]="狀態"; 
$LANG['Menu'][30]="日誌"; 
$LANG['Menu'][31]="服務台"; 
$LANG['Menu'][32]="消耗品"; 
$LANG['Menu'][34]="電話"; 
$LANG['Menu'][35]="個人配置"; 
$LANG['Menu'][36]="群組"; 
$LANG['Menu'][37]="權限"; 
$LANG['Menu'][38]="財產目錄"; 
$LANG['Menu'][39]="接收端"; 
$LANG['Menu'][40]="書籤"; 
$LANG['Menu'][41]="權限"; 
$LANG['Menu'][42]="議程"; 
$LANG['Menu'][43]="所有服務等級"; 

$LANG['monitors'][14]="話筒"; 
$LANG['monitors'][15]="揚聲器"; 
$LANG['monitors'][18]="標誌"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="大小"; 
$LANG['monitors'][31]="顯示埠號"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 
$LANG['monitors'][34]="HDMI"; 

$LANG['networking'][4]="網路端口"; 
$LANG['networking'][5]="記憶體 (MB)"; 
$LANG['networking'][6]="網路端口"; 
$LANG['networking'][10]="沒有發現網路端口"; 
$LANG['networking'][11]="發現網路端口"; 
$LANG['networking'][12]="發現網絡端口"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="連接到"; 
$LANG['networking'][19]="新增網路端口…"; 
$LANG['networking'][21]="Port號"; 
$LANG['networking'][25]="開"; 
$LANG['networking'][44]="端口"; 
$LANG['networking'][46]="新增數個端口..."; 
$LANG['networking'][48]="到"; 
$LANG['networking'][51]="網路點"; 
$LANG['networking'][52]="網路商店"; 
$LANG['networking'][55]="關聯一個VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="在下面清單中選擇或指定一個 MAC address"; 
$LANG['networking'][58]="刪除一個 VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Mask"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][0]="OCSNG"; 
$LANG['ocsconfig'][1]="OCSNG資料庫的使用者"; 
$LANG['ocsconfig'][2]="OCSNG的資料庫主機"; 
$LANG['ocsconfig'][3]="OCSNG使用者的密碼"; 
$LANG['ocsconfig'][4]="OCSNG資料庫名稱"; 
$LANG['ocsconfig'][5]="導入選項"; 
$LANG['ocsconfig'][6]="連接到OCSNG資料庫"; 
$LANG['ocsconfig'][7]="OCSNG資料庫使用UTF8"; 
$LANG['ocsconfig'][8]="無法新增。 OCSNG伺服器已經存在."; 
$LANG['ocsconfig'][9]="排除下列標籤 (分隔 $, 全部皆否)"; 
$LANG['ocsconfig'][10]="全部導入"; 
$LANG['ocsconfig'][12]="單位導入"; 
$LANG['ocsconfig'][13]="單位導入： 所有導入都是 'as-is'"; 
$LANG['ocsconfig'][14]="全部導入：導入所有,但是資料是總體管理(不會重複大量出現)"; 
$LANG['ocsconfig'][15]="沒有導入： 插件將不會導入這些項目"; 
$LANG['ocsconfig'][16]="預設狀態"; 
$LANG['ocsconfig'][17]="對以下標記限制導入(以$,分隔為全部沒有)"; 
$LANG['ocsconfig'][18]="首先, 在OCSNG管理介面檢查重複項目"; 
$LANG['ocsconfig'][19]="單位導入,根據序號"; 
$LANG['ocsconfig'][20]="OCSNG刪除電腦的行為"; 
$LANG['ocsconfig'][21]="查看OCSNG訊息"; 
$LANG['ocsconfig'][22]="手動執行OCSNG同步"; 
$LANG['ocsconfig'][23]="啟用 OCSNG 模式"; 
$LANG['ocsconfig'][24]="OCSNG模式"; 
$LANG['ocsconfig'][27]="一般資訊"; 
$LANG['ocsconfig'][28]="從OCSNG執行項目同步"; 
$LANG['ocsconfig'][36]="數據機"; 
$LANG['ocsconfig'][37]="端口"; 
$LANG['ocsconfig'][38]="使用OCSNG軟體辭典"; 
$LANG['ocsconfig'][39]="OCSNG標籤"; 
$LANG['ocsconfig'][40]="使用cron同步的電腦數量"; 
$LANG['ocsconfig'][41]="註冊"; 
$LANG['ocsconfig'][43]="OCSNG管理的資訊"; 
$LANG['ocsconfig'][48]="斷線時的行為"; 
$LANG['ocsconfig'][49]="垃圾"; 
$LANG['ocsconfig'][52]="機器自動連接"; 
$LANG['ocsconfig'][53]="啟動自動連線"; 
$LANG['ocsconfig'][54]="限有規範的電腦"; 
$LANG['ocsconfig'][55]="搜尋有狀態的電腦"; 
$LANG['ocsconfig'][56]="空"; 
$LANG['ocsconfig'][57]="等於"; 
$LANG['ocsconfig'][58]="透過一個OCSNG自動連接GLPI 電腦.<br>此選項只考慮以腳本做同步,而非手動做同步."; 
$LANG['ocsconfig'][59]="OCSNG控制台的網址"; 
$LANG['ocsconfig'][60]="僅導入裝置序號"; 

$LANG['ocsng'][0]="OCS固定資產NG"; 
$LANG['ocsng'][1]="同步已經導入的電腦"; 
$LANG['ocsng'][2]="導入新增的電腦"; 
$LANG['ocsng'][3]="清除 GLPI 和 OCSNG 之間的連結"; 
$LANG['ocsng'][4]="新增的OCS電腦連結到GLPI內已存在的電腦"; 
$LANG['ocsng'][5]="導入新增的電腦"; 
$LANG['ocsng'][6]="自動更新"; 
$LANG['ocsng'][7]="從OCSNG導入了"; 
$LANG['ocsng'][9]="沒有新電腦需要導入"; 
$LANG['ocsng'][10]="已於OCSNG更新電腦"; 
$LANG['ocsng'][11]="更新電腦"; 
$LANG['ocsng'][12]="沒有新電腦需更新"; 
$LANG['ocsng'][13]="導入日期在GLPI"; 
$LANG['ocsng'][14]="最新的OCSNG盤點日期"; 
$LANG['ocsng'][15]="沒有欄位被鎖定"; 
$LANG['ocsng'][16]="被鎖定的欄位"; 
$LANG['ocsng'][18]="與OCSNG資料庫的連接成功"; 
$LANG['ocsng'][19]="正確的OCSNG設定及版本"; 
$LANG['ocsng'][20]="無效OCSNG版本： 要要RC3"; 
$LANG['ocsng'][21]="與OCS NG資料庫的連接發生了錯誤"; 
$LANG['ocsng'][22]="注意! 導入的數據(檢視您的設定)將覆蓋現有數據"; 
$LANG['ocsng'][23]="無法導入，GLPI電腦已與OCSNG有關聯的項目"; 
$LANG['ocsng'][26]="選擇一個OCSNG伺服器"; 
$LANG['ocsng'][27]="沒有定義任何OCSNG伺服器"; 
$LANG['ocsng'][28]="OCSNG伺服器"; 
$LANG['ocsng'][29]="OCS伺服器"; 
$LANG['ocsng'][30]="被鎖定的顯示器 (s)"; 
$LANG['ocsng'][32]="被鎖定的裝置(s)"; 
$LANG['ocsng'][34]="被鎖定的印表機(s)"; 
$LANG['ocsng'][37]="啟用預覽"; 
$LANG['ocsng'][38]="關閉預覽"; 
$LANG['ocsng'][39]="目標位置"; 
$LANG['ocsng'][40]="合乎規則嗎?"; 
$LANG['ocsng'][41]="手動導入模式"; 
$LANG['ocsng'][42]="無效的 OCSNG 設定 (TRACE_DELETED 必須被啟用)"; 
$LANG['ocsng'][43]="OCSNG資料庫存取被拒 (需要有寫入hardware.CHECKSUM的權限)"; 
$LANG['ocsng'][44]="OCSNG資料庫存取被拒 (需要有刪除deleted_equiv table的權限)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="在OCSNG中刪除"; 
$LANG['ocsng'][47]="和OCS電腦連結"; 
$LANG['ocsng'][48]="電腦的OCS ID 已變更"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="被鎖定的 IP(s)"; 
$LANG['ocsng'][52]="被鎖定的軟體(s)"; 
$LANG['ocsng'][53]="OCSNG連結"; 
$LANG['ocsng'][54]="OCS 同步後已將軟體刪除"; 
$LANG['ocsng'][55]="儲存裝置被鎖定"; 
$LANG['ocsng'][56]="已鎖定的元件"; 
$LANG['ocsng'][57]="OCS 介面"; 
$LANG['ocsng'][58]="OCSNG連結"; 
$LANG['ocsng'][59]="已存在於GLPI"; 
$LANG['ocsng'][60]="已存在於OCSNG"; 
$LANG['ocsng'][61]="沒有項目需清除"; 
$LANG['ocsng'][62]="實體目標的電腦"; 
$LANG['ocsng'][67]="可以連結"; 
$LANG['ocsng'][68]="拒絕匯入"; 
$LANG['ocsng'][69]="新電腦已建立於GLPI"; 
$LANG['ocsng'][70]="已導入的電腦"; 
$LANG['ocsng'][71]="已同步的電腦"; 
$LANG['ocsng'][72]="沒有電腦檢查規則"; 
$LANG['ocsng'][73]="已連結的電腦"; 
$LANG['ocsng'][74]="未修改的電腦"; 
$LANG['ocsng'][75]="重複的電腦"; 
$LANG['ocsng'][76]="OCS連結統計"; 
$LANG['ocsng'][77]="執行完成"; 
$LANG['ocsng'][78]="如果可能的話連結，否則拒絕導入"; 
$LANG['ocsng'][79]="如果可能的話連結"; 
$LANG['ocsng'][80]="依導入規則被拒絕的電腦"; 

$LANG['pager'][1]="到"; 
$LANG['pager'][2]="從"; 
$LANG['pager'][3]="在"; 
$LANG['pager'][4]="顯示"; 
$LANG['pager'][5]="項目"; 
$LANG['pager'][6]="從"; 
$LANG['pager'][7]="到"; 

$LANG['peripherals'][18]="品牌"; 
$LANG['peripherals'][31]="全部管理"; 
$LANG['peripherals'][32]="實體管理"; 
$LANG['peripherals'][33]="管理類型"; 

$LANG['phones'][36]="電源供應器"; 
$LANG['phones'][38]="耳機"; 
$LANG['phones'][39]="揚聲器"; 
$LANG['phones'][40]="行數"; 

$LANG['planning'][1]="輸入日期錯誤,開始日期晚於結束日期"; 
$LANG['planning'][2]="使用者所選定的時間表已經被佔用："; 
$LANG['planning'][3]="期間"; 
$LANG['planning'][5]="天"; 
$LANG['planning'][6]="星期"; 
$LANG['planning'][8]="固定資產追蹤"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="以 ical 格式下載日曆"; 
$LANG['planning'][13]="Webcal:// 同步"; 
$LANG['planning'][15]="您的計劃"; 
$LANG['planning'][16]="資訊"; 
$LANG['planning'][17]="去執行"; 
$LANG['planning'][18]="完成"; 

$LANG['plugins'][0]="插件清單"; 
$LANG['plugins'][1]="刪除或更新它，否則 GLPI將無法正常工作。"; 
$LANG['plugins'][2]="已安裝 / 未設定"; 
$LANG['plugins'][3]="已安裝 / 未啟用"; 
$LANG['plugins'][4]="錯誤 / 清除"; 
$LANG['plugins'][5]="沒有進階的功能"; 
$LANG['plugins'][6]="要更新"; 
$LANG['plugins'][7]="沒有安裝插件"; 
$LANG['plugins'][8]="檢視插件目錄"; 
$LANG['plugins'][9]="作者"; 
$LANG['plugins'][10]="與此GLPI版本不兼容的插件"; 

$LANG['printers'][14]="序列"; 
$LANG['printers'][15]="Parallel"; 
$LANG['printers'][18]="Ports"; 
$LANG['printers'][26]="現在表的頁數"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="根據模板新增印表機"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="初始頁面數量器"; 
$LANG['printers'][31]="列印"; 
$LANG['printers'][32]="驅動程式"; 

$LANG['problem'][0]="問題"; 
$LANG['problem'][1]="已接受"; 
$LANG['problem'][2]="觀察中"; 
$LANG['problem'][3]="分析"; 
$LANG['problem'][4]="影響"; 
$LANG['problem'][5]="原因"; 
$LANG['problem'][6]="徵狀"; 
$LANG['problem'][7]="建立這個問題單的問題"; 
$LANG['problem'][8]="新問題"; 
$LANG['problem'][9]="更新問題"; 
$LANG['problem'][10]="問題已解決"; 
$LANG['problem'][11]="結束問題"; 
$LANG['problem'][12]="刪除問題"; 

$LANG['profiles'][0]="全部權利"; 
$LANG['profiles'][1]="實體權利"; 
$LANG['profiles'][2]="個人配置介面"; 
$LANG['profiles'][3]="登入時建立問題單"; 
$LANG['profiles'][4]="問題單相關的群組新增一個後續追蹤"; 
$LANG['profiles'][5]="創建一張問題單"; 
$LANG['profiles'][6]="新增問題單後續 (作者)"; 
$LANG['profiles'][7]="顯示所有問題單"; 
$LANG['profiles'][8]="觀示所有後續追蹤(公開和私有)"; 
$LANG['profiles'][9]="顯示公開後續追蹤"; 
$LANG['profiles'][10]="讀"; 
$LANG['profiles'][11]="寫"; 
$LANG['profiles'][12]="不能進入"; 
$LANG['profiles'][13]="預設配置文件"; 
$LANG['profiles'][14]="刪除問題單"; 
$LANG['profiles'][15]="所有問題單新增後續追綜"; 
$LANG['profiles'][16]="重為問題單負責人"; 
$LANG['profiles'][17]="竊取問題單"; 
$LANG['profiles'][18]="更新問題單"; 
$LANG['profiles'][19]="指派問題單"; 
$LANG['profiles'][20]="檢視個人計劃"; 
$LANG['profiles'][21]="觀看所有計劃"; 
$LANG['profiles'][22]="個人配置"; 
$LANG['profiles'][23]="預借管理"; 
$LANG['profiles'][24]="更新密碼"; 
$LANG['profiles'][25]="查看所有問題"; 
$LANG['profiles'][26]="依群組顯示已建立的問題單"; 
$LANG['profiles'][27]="依我的群組顯示硬體"; 
$LANG['profiles'][28]="遞迴"; 
$LANG['profiles'][29]="動態"; 
$LANG['profiles'][32]="查看已分配的問題單 (個人 + 群組關連)"; 
$LANG['profiles'][33]="無此使用者"; 
$LANG['profiles'][34]="標題"; 
$LANG['profiles'][35]="更新所有後續追蹤"; 
$LANG['profiles'][36]="在我的群組查看所有人的時間表"; 
$LANG['profiles'][37]="預設實體"; 
$LANG['profiles'][38]="可見"; 
$LANG['profiles'][39]="分配"; 
$LANG['profiles'][40]="更新"; 
$LANG['profiles'][41]="建立"; 
$LANG['profiles'][42]="關連"; 
$LANG['profiles'][43]="使用者認證和同步方法"; 
$LANG['profiles'][44]="變更優先次序"; 
$LANG['profiles'][45]="所有問題單新增一項作業"; 
$LANG['profiles'][46]="修改所有的作業"; 
$LANG['profiles'][47]="從外部來源新增使用者"; 
$LANG['profiles'][48]="建立一個驗證請求"; 
$LANG['profiles'][49]="驗證問題單"; 
$LANG['profiles'][50]="更新後續追蹤(作者)"; 
$LANG['profiles'][51]="刪除所有後續追蹤"; 
$LANG['profiles'][52]="更新所有的問題"; 
$LANG['profiles'][53]="查看問題（角色）"; 
$LANG['profiles'][54]="刪除"; 
$LANG['profiles'][55]="查看所有變更"; 
$LANG['profiles'][56]="更新所有的變更"; 
$LANG['profiles'][57]="查看與我相關的所有變更"; 

$LANG['registry'][1]="巢狀"; 
$LANG['registry'][2]="路徑"; 
$LANG['registry'][3]="Key/值"; 
$LANG['registry'][4]="找到註冊表中 key(s)"; 
$LANG['registry'][5]="沒有找到註冊表中的key"; 
$LANG['registry'][6]="OCS 名稱"; 

$LANG['reminder'][0]="個人註解"; 
$LANG['reminder'][1]="公開註解"; 
$LANG['reminder'][2]="目標"; 
$LANG['reminder'][3]="沒有限制"; 
$LANG['reminder'][6]="新增新註解"; 
$LANG['reminder'][12]="新增到日曆"; 
$LANG['reminder'][15]="沒有標題"; 
$LANG['reminder'][16]="全部註解"; 

$LANG['reports'][0]="選擇一個您想要形成的報告"; 
$LANG['reports'][4]="硬體名單根據合約"; 
$LANG['reports'][11]="在合約內的硬體"; 
$LANG['reports'][12]="硬體類型"; 
$LANG['reports'][13]="日期"; 
$LANG['reports'][15]="顯示報告"; 
$LANG['reports'][19]="聯絡人姓名"; 
$LANG['reports'][26]="預設報告"; 
$LANG['reports'][27]="根據合約"; 
$LANG['reports'][28]="根據年"; 
$LANG['reports'][33]="網絡報告"; 
$LANG['reports'][36]="連接的設備"; 
$LANG['reports'][37]="網絡點"; 
$LANG['reports'][39]="根據地點"; 
$LANG['reports'][41]="根據硬體"; 
$LANG['reports'][42]="根據網絡點"; 
$LANG['reports'][46]="硬體端口"; 
$LANG['reports'][47]="設備端口"; 
$LANG['reports'][49]="網絡硬體報告"; 
$LANG['reports'][51]="根據網絡點的網絡報告"; 
$LANG['reports'][52]="交換器"; 
$LANG['reports'][54]="根據地點的網絡報告"; 
$LANG['reports'][57]="原料單"; 
$LANG['reports'][58]="根據年的設備報告"; 
$LANG['reports'][60]="開始日期"; 
$LANG['reports'][61]="截止日期"; 
$LANG['reports'][62]="硬體會計和管理資訊"; 
$LANG['reports'][63]="其它會計和管理資訊(授權、墨水夾、消耗品)"; 
$LANG['reports'][64]="決議通過日期"; 

$LANG['reservation'][1]="保留的項目"; 
$LANG['reservation'][2]="設備暫時無法使用"; 
$LANG['reservation'][3]="設定為 不可用"; 
$LANG['reservation'][4]="可用"; 
$LANG['reservation'][5]="設定為 可用"; 
$LANG['reservation'][6]="禁止預借"; 
$LANG['reservation'][7]="授權保留"; 
$LANG['reservation'][8]="預訂"; 
$LANG['reservation'][9]="預訂一個項目"; 
$LANG['reservation'][10]="可保留的項目"; 
$LANG['reservation'][11]="無法使用"; 
$LANG['reservation'][16]="對"; 
$LANG['reservation'][17]="從"; 
$LANG['reservation'][18]="需求的項目在該時段已經被預訂."; 
$LANG['reservation'][20]="回到日曆"; 
$LANG['reservation'][21]="看預訂"; 
$LANG['reservation'][22]="修改批注"; 
$LANG['reservation'][25]="含可供出借的硬體"; 
$LANG['reservation'][27]="重複幾次"; 
$LANG['reservation'][28]="星期"; 
$LANG['reservation'][29]="日"; 
$LANG['reservation'][30]="次數單位"; 
$LANG['reservation'][35]="進行中和未來的的預借"; 
$LANG['reservation'][36]="過去的預借"; 
$LANG['reservation'][37]="沒有預借"; 
$LANG['reservation'][38]="你確定要從借出項目刪除這個項目 ?"; 
$LANG['reservation'][39]="這將刪除所有的預借資訊."; 
$LANG['reservation'][40]="今天到期的預借物件"; 

$LANG['rulesengine'][0]="是"; 
$LANG['rulesengine'][1]="不是"; 
$LANG['rulesengine'][3]="不包含"; 
$LANG['rulesengine'][4]="開始 with"; 
$LANG['rulesengine'][5]="完成 by"; 
$LANG['rulesengine'][6]="標準"; 
$LANG['rulesengine'][7]="作用"; 
$LANG['rulesengine'][8]="規則管理"; 
$LANG['rulesengine'][9]="邏輯運算"; 
$LANG['rulesengine'][10]="職位"; 
$LANG['rulesengine'][11]="作用類型"; 
$LANG['rulesengine'][12]="欄位"; 
$LANG['rulesengine'][13]="值"; 
$LANG['rulesengine'][14]="狀況"; 
$LANG['rulesengine'][15]="原因"; 
$LANG['rulesengine'][16]="標準"; 
$LANG['rulesengine'][17]="規則"; 
$LANG['rulesengine'][18]="電腦分配給實體的規則"; 
$LANG['rulesengine'][19]="認證分配規則"; 
$LANG['rulesengine'][20]="套用規則"; 
$LANG['rulesengine'][21]="規則適用於子實體"; 
$LANG['rulesengine'][22]="分配"; 
$LANG['rulesengine'][23]="本機規則"; 
$LANG['rulesengine'][24]="規則類型"; 
$LANG['rulesengine'][25]="電腦名稱"; 
$LANG['rulesengine'][26]="正規檢核"; 
$LANG['rulesengine'][27]="正規不符合"; 
$LANG['rulesengine'][28]="問題單業務規則"; 
$LANG['rulesengine'][29]="規則清單"; 
$LANG['rulesengine'][30]="作用"; 
$LANG['rulesengine'][31]="存在"; 
$LANG['rulesengine'][32]="不存在"; 
$LANG['rulesengine'][33]="下拉辭典"; 
$LANG['rulesengine'][35]="軟體辭典"; 
$LANG['rulesengine'][36]="製造商辭典"; 
$LANG['rulesengine'][37]="軟體類別分類規則"; 
$LANG['rulesengine'][38]="重新計算"; 
$LANG['rulesengine'][39]="印表機辭典"; 
$LANG['rulesengine'][40]="類別"; 
$LANG['rulesengine'][41]="驗證"; 
$LANG['rulesengine'][45]="正規表示法的值"; 
$LANG['rulesengine'][46]="指派: 設備 IP address"; 
$LANG['rulesengine'][47]="指派: 設備 name + domain"; 
$LANG['rulesengine'][48]="指派 設備"; 
$LANG['rulesengine'][49]="指派: 設備 MAC address"; 
$LANG['rulesengine'][50]="電腦型號辭典"; 
$LANG['rulesengine'][51]="顯示器辭典"; 
$LANG['rulesengine'][52]="電話辭典"; 
$LANG['rulesengine'][53]="外圍設備型號辭典"; 
$LANG['rulesengine'][54]="印表型號辭典"; 
$LANG['rulesengine'][55]="網路型號辭典"; 
$LANG['rulesengine'][56]="型號"; 
$LANG['rulesengine'][57]="導入和連接電腦的規則"; 
$LANG['rulesengine'][60]="電腦類型辭典"; 
$LANG['rulesengine'][61]="顯示器類型辭典"; 
$LANG['rulesengine'][62]="電話類型辭典"; 
$LANG['rulesengine'][63]="外圍設備類型辭典"; 
$LANG['rulesengine'][64]="印表機類型辭典"; 
$LANG['rulesengine'][65]="網路設備類型辭典"; 
$LANG['rulesengine'][66]="類型"; 
$LANG['rulesengine'][67]="作業系統辭典"; 
$LANG['rulesengine'][68]="Service Pack 辭典"; 
$LANG['rulesengine'][69]="OS版本辭典"; 
$LANG['rulesengine'][70]="透過個郵件收件人建立問題單指派規則"; 
$LANG['rulesengine'][76]="依詞典重命名"; 
$LANG['rulesengine'][77]="辭典"; 
$LANG['rulesengine'][78]="版本"; 
$LANG['rulesengine'][79]="新增正規結果"; 
$LANG['rulesengine'][80]="總體的辭典"; 
$LANG['rulesengine'][81]="規則的結果"; 
$LANG['rulesengine'][82]="詳細結果"; 
$LANG['rulesengine'][83]="你可以使用字串 #0 改變正規表示法的結果"; 
$LANG['rulesengine'][84]="測試規則"; 
$LANG['rulesengine'][85]="正規表示法的結果"; 
$LANG['rulesengine'][86]="透過辭典刪除將影響軟體類別"; 
$LANG['rulesengine'][87]="透過GLPI辭典刪除軟體"; 
$LANG['rulesengine'][90]="執行中..."; 
$LANG['rulesengine'][91]="執行完畢."; 
$LANG['rulesengine'][92]="在依辭典執行變更名稱前警告"; 
$LANG['rulesengine'][93]="警告! 這項作業會將軟體丟到垃圾桶.<br>確認已通知使用者."; 
$LANG['rulesengine'][94]="融合"; 
$LANG['rulesengine'][95]="製造商的選擇"; 
$LANG['rulesengine'][96]="依辭典替換製造商(s)<br> ( ----- = All)"; 
$LANG['rulesengine'][97]="沒有項目進行測試"; 
$LANG['rulesengine'][100]="緩存訊息"; 
$LANG['rulesengine'][102]="規則名稱"; 
$LANG['rulesengine'][103]="緩存中的對象"; 
$LANG['rulesengine'][104]="初始值"; 
$LANG['rulesengine'][105]="修改後的值"; 
$LANG['rulesengine'][106]="未變更"; 
$LANG['rulesengine'][107]="停用"; 
$LANG['rulesengine'][108]="原始的"; 
$LANG['rulesengine'][110]="權利移轉"; 
$LANG['rulesengine'][111]="實體移轉"; 
$LANG['rulesengine'][112]="權利和實體移轉"; 
$LANG['rulesengine'][120]="該引擎停止第一個檢查站規則."; 
$LANG['rulesengine'][121]="該引擎處理所有的規則."; 
$LANG['rulesengine'][122]="該引擎將結果傳給下一個規則."; 
$LANG['rulesengine'][129]="從郵件domain實體"; 
$LANG['rulesengine'][130]="實體根據LDAP訊息"; 
$LANG['rulesengine'][131]="從 TAG實體"; 
$LANG['rulesengine'][132]="導入不要知道"; 
$LANG['rulesengine'][133]="自domain實體"; 
$LANG['rulesengine'][134]="退回電子郵件（不含電子郵件回覆）"; 
$LANG['rulesengine'][135]="退回電子郵件（含電子郵件回覆）"; 
$LANG['rulesengine'][137]="LDAP的標準"; 
$LANG['rulesengine'][138]="LDAP的標準"; 
$LANG['rulesengine'][140]="新增一個準則"; 
$LANG['rulesengine'][142]="不導入電子郵件名單"; 
$LANG['rulesengine'][144]="實體基於使用者的個人資料"; 
$LANG['rulesengine'][145]="使用者使用單一的配置文件"; 
$LANG['rulesengine'][146]="使用者特色配置文件"; 
$LANG['rulesengine'][147]="使用者具有一個配置文件"; 
$LANG['rulesengine'][148]="郵件的domain已知"; 
$LANG['rulesengine'][149]="從 LDAP目錄導入群組"; 
$LANG['rulesengine'][150]="使用規則的物件已被已被停用。"; 
$LANG['rulesengine'][151]="已存在於 GLPI"; 
$LANG['rulesengine'][152]="導入的電腦"; 
$LANG['rulesengine'][154]="在GLPI內是空的"; 
$LANG['rulesengine'][155]="與電腦連結"; 

$LANG['satisfaction'][0]="滿意度"; 
$LANG['satisfaction'][1]="該問題單的滿意度調查結果"; 
$LANG['satisfaction'][2]="沒有調查產生"; 
$LANG['satisfaction'][3]="滿意度調查"; 
$LANG['satisfaction'][4]="滿意度調查回應日期"; 
$LANG['satisfaction'][6]="創建日期的滿意度調查"; 
$LANG['satisfaction'][7]="滿意度"; 
$LANG['satisfaction'][8]="滿意度調查的意見"; 
$LANG['satisfaction'][9]="內部調查"; 
$LANG['satisfaction'][10]="外部調查"; 
$LANG['satisfaction'][12]="邀請填寫調查"; 
$LANG['satisfaction'][13]="已開啟"; 
$LANG['satisfaction'][14]="解答"; 

$LANG['search'][0]="搜尋"; 
$LANG['search'][1]="所有"; 
$LANG['search'][2]="包含"; 
$LANG['search'][3]="在"; 
$LANG['search'][4]="排序"; 
$LANG['search'][5]="選擇過大，已停用此大量動作。"; 
$LANG['search'][6]="為了增加上限：請在PHP配置更改max_input_vars或suhosin.post.max_vars。"; 
$LANG['search'][7]="不在"; 
$LANG['search'][8]="開始日期"; 
$LANG['search'][9]="結束日期"; 
$LANG['search'][11]="檢視的項目"; 
$LANG['search'][12]="指定一結束日期"; 
$LANG['search'][15]="沒有發現項目"; 
$LANG['search'][16]="至少"; 
$LANG['search'][17]="新增搜尋標準"; 
$LANG['search'][18]="刪除搜尋標準"; 
$LANG['search'][19]="新增總體的搜尋標準"; 
$LANG['search'][20]="刪除總體的搜尋標準"; 
$LANG['search'][21]="小於"; 
$LANG['search'][22]="大於"; 
$LANG['search'][23]="之前"; 
$LANG['search'][24]="之後"; 

$LANG['setup'][0]="下拉列表"; 
$LANG['setup'][1]="查看在標籤中的數量"; 
$LANG['setup'][2]="新增使用者..."; 
$LANG['setup'][3]="LDAP 連結"; 
$LANG['setup'][4]="電腦類型"; 
$LANG['setup'][6]="個人化"; 
$LANG['setup'][7]="CSV的分隔符號"; 
$LANG['setup'][8]="以預設值開啟會計和管理訊息"; 
$LANG['setup'][9]="網路界面"; 
$LANG['setup'][10]="顯示姓名"; 
$LANG['setup'][11]="自動更新問題單清單"; 
$LANG['setup'][12]="創建問題單時，預先選我做為技術人員"; 
$LANG['setup'][14]="電子郵件"; 
$LANG['setup'][15]="Emails"; 
$LANG['setup'][16]="SELinux的模式為"; 
$LANG['setup'][17]="SELinux布林設定於"; 
$LANG['setup'][18]="登入名稱"; 
$LANG['setup'][19]="密碼"; 
$LANG['setup'][20]="密碼確認"; 
$LANG['setup'][21]="錯誤：這兩個密碼不相同"; 
$LANG['setup'][22]="搜尋影引擎"; 
$LANG['setup'][23]="上次標準"; 
$LANG['setup'][24]="預設標準"; 
$LANG['setup'][25]="全部查尋"; 
$LANG['setup'][35]="兆赫"; 
$LANG['setup'][39]="根據個人的預設"; 
$LANG['setup'][40]="優先顯示新問題單？"; 
$LANG['setup'][41]="語系選擇"; 
$LANG['setup'][42]="網路設備類型"; 
$LANG['setup'][43]="印表機類型"; 
$LANG['setup'][44]="顯示器類型"; 
$LANG['setup'][45]="機殼類型"; 
$LANG['setup'][46]="預設值"; 
$LANG['setup'][47]="預設圖表格式"; 
$LANG['setup'][48]="預設值"; 
$LANG['setup'][50]="根據類別然後項目"; 
$LANG['setup'][51]="根據項目然後類別"; 
$LANG['setup'][52]="自動分配問題單"; 
$LANG['setup'][63]="注意，您將刪除一個用於一個或更多項目的標題"; 
$LANG['setup'][64]="如果您確定刪除，這個標題的項目將賦給空域"; 
$LANG['setup'][65]="您能將一個替換這個標題的所有事件："; 
$LANG['setup'][67]="外在認證"; 
$LANG['setup'][69]="設備型號"; 
$LANG['setup'][70]="一般設定"; 
$LANG['setup'][71]="軔體"; 
$LANG['setup'][74]="您不能刪除那個地方，因為它有子地點"; 
$LANG['setup'][75]="作為子項目"; 
$LANG['setup'][76]="子項來自於"; 
$LANG['setup'][79]="問題單的類別"; 
$LANG['setup'][80]="第三方類型"; 
$LANG['setup'][81]="文件標題"; 
$LANG['setup'][82]="聯絡人類型"; 
$LANG['setup'][83]="項目狀態"; 
$LANG['setup'][84]="墨水夾類型"; 
$LANG['setup'][85]="合約類型"; 
$LANG['setup'][86]="記憶體類型"; 
$LANG['setup'][87]="知識庫類別"; 
$LANG['setup'][88]="網路"; 
$LANG['setup'][89]="網域"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="電腦型號"; 
$LANG['setup'][92]="消耗品種類"; 
$LANG['setup'][93]="界面類型（硬碟...）"; 
$LANG['setup'][94]="監視器型號"; 
$LANG['setup'][95]="網絡模式"; 
$LANG['setup'][96]="印表機模式"; 
$LANG['setup'][97]="外圍設備模式"; 
$LANG['setup'][98]="作業類別"; 
$LANG['setup'][99]="版本編號"; 
$LANG['setup'][100]="房號"; 
$LANG['setup'][101]="自動操作的最大數量（由命令列運行）"; 
$LANG['setup'][102]="日誌等級"; 
$LANG['setup'][103]="1- 危急 (只記錄登入異常)"; 
$LANG['setup'][104]="2 -嚴重(未使用)"; 
$LANG['setup'][105]="3- 重要 (成功登入)"; 
$LANG['setup'][106]="4 -通知(新增，刪除，追蹤)"; 
$LANG['setup'][107]="5 -完成(所有)"; 
$LANG['setup'][108]="摘要文字方塊最大字元數"; 
$LANG['setup'][109]="資料庫保留LOG的期限 (天, 0 無限制)"; 
$LANG['setup'][110]="在首頁顯示新問題單"; 
$LANG['setup'][111]="每頁需列印項目的數量"; 
$LANG['setup'][112]="每個項目清單的字符最大數"; 
$LANG['setup'][113]="預設語言"; 
$LANG['setup'][114]="優先權顏色"; 
$LANG['setup'][115]="墨水夾和消耗品數量的預設門檻值"; 
$LANG['setup'][117]="批准常見問題解答的匿名視圖"; 
$LANG['setup'][118]="登入畫面文字"; 
$LANG['setup'][119]="最小化動態搜尋下拉列表的文字"; 
$LANG['setup'][120]="使用Ajax"; 
$LANG['setup'][121]="以字元強制顯示全部的下拉列表（萬用字元）"; 
$LANG['setup'][122]="當萬用字元未使用時,在下拉選單顯示項目的最大數量"; 
$LANG['setup'][123]="不使用Ajax,如果項目的數量是少於 (0=決不)"; 
$LANG['setup'][124]="自動地新增一個外在認證來源的使用者"; 
$LANG['setup'][125]="... 從外部來源"; 
$LANG['setup'][126]="自動地新增一個外部來源的使用者"; 
$LANG['setup'][127]="自動完成文字欄位"; 
$LANG['setup'][128]="日期格式"; 
$LANG['setup'][129]="顯示GLPI ID"; 
$LANG['setup'][130]="用於下一個/上一個項目"; 
$LANG['setup'][131]="每頁顯示數量"; 
$LANG['setup'][132]="下拉清單顯示完整的名稱"; 
$LANG['setup'][133]="在首頁上的結果數量"; 
$LANG['setup'][135]="正常"; 
$LANG['setup'][136]="翻譯"; 
$LANG['setup'][137]="除錯"; 
$LANG['setup'][138]="使用GLPI模式"; 
$LANG['setup'][139]="公共"; 
$LANG['setup'][140]="類型"; 
$LANG['setup'][145]="操作系統"; 
$LANG['setup'][147]="Ajax"; 
$LANG['setup'][148]="時間的間距"; 
$LANG['setup'][149]="金額顯示的小數位數"; 
$LANG['setup'][150]="數字格式"; 
$LANG['setup'][154]="基本的 DN"; 
$LANG['setup'][155]="rootdn (非匿名)"; 
$LANG['setup'][156]="通行證(非匿名)"; 
$LANG['setup'][157]="PHP解析器未安裝LDAP擴展"; 
$LANG['setup'][158]="不能用LDAP作為連接的外部來源"; 
$LANG['setup'][159]="連接過濾器"; 
$LANG['setup'][162]="電子郵件伺服器設定"; 
$LANG['setup'][164]="電子郵件Domain名稱 <br>(使用者的電子郵件是 login@domain)"; 
$LANG['setup'][165]="您的PHP解析器沒有編譯IMAP的功能"; 
$LANG['setup'][166]="無法使用電子郵件作為外部連接的來源"; 
$LANG['setup'][167]="綁定到LDAP目錄"; 
$LANG['setup'][168]="連接選項"; 
$LANG['setup'][169]="郵件文件夾（選用，常用收件箱）"; 
$LANG['setup'][170]="結果的連接參量"; 
$LANG['setup'][171]="端口（選用）"; 
$LANG['setup'][172]="端口(預設=389)"; 
$LANG['setup'][174]="CAS主機"; 
$LANG['setup'][175]="端口"; 
$LANG['setup'][176]="根目錄(任意)"; 
$LANG['setup'][177]="CAS認證"; 
$LANG['setup'][178]="PHP解析器未安裝 CURL 或 DOMXML延伸功能"; 
$LANG['setup'][179]="無法用CAS作為連接的外部來源"; 
$LANG['setup'][180]="使用TLS"; 
$LANG['setup'][181]="ldap_start_tls不存在"; 
$LANG['setup'][182]="登出後返回的 URL"; 
$LANG['setup'][185]="記載到日誌文件中 (SQL, 電子郵件, 自動執行...)"; 
$LANG['setup'][186]="LDAP目錄時區"; 
$LANG['setup'][187]="GLPI 伺服器時區"; 
$LANG['setup'][190]="x509 認證"; 
$LANG['setup'][191]="對x509的電子郵件屬性"; 
$LANG['setup'][192]="啟用"; 
$LANG['setup'][193]="記載在登入HTTP請求的欄位"; 
$LANG['setup'][194]="訪問控制和額外的信息"; 
$LANG['setup'][195]="保持狀態"; 
$LANG['setup'][196]="清除狀態"; 
$LANG['setup'][197]="複製電腦狀態"; 
$LANG['setup'][198]="設定狀態"; 
$LANG['setup'][199]="從login@domain刪除登入Domain"; 
$LANG['setup'][200]="無限"; 
$LANG['setup'][201]="電子郵件後續追蹤設定"; 
$LANG['setup'][202]="使用郵件後續追蹤"; 
$LANG['setup'][203]="管理員E-Mail"; 
$LANG['setup'][204]="郵件署名"; 
$LANG['setup'][205]="發送測試郵件到管理員"; 
$LANG['setup'][206]="發送測試郵件到管理員失敗"; 
$LANG['setup'][207]="轉發系統管理員的信到 Email (視需要設定)"; 
$LANG['setup'][208]="管理員名稱"; 
$LANG['setup'][209]="回應名稱（如有必要）"; 
$LANG['setup'][217]="PHP郵件功能未知或沒有在您的系統中被啟用"; 
$LANG['setup'][218]="對SMTP的使用是需要的"; 
$LANG['setup'][219]="允許匿名創建問題單(helpdesk.html)"; 
$LANG['setup'][220]="允許匿名後續追蹤(收件人)"; 
$LANG['setup'][221]="會計年度初期(天和月)"; 
$LANG['setup'][223]="計劃日程表的限制"; 
$LANG['setup'][227]="應用程式的URL"; 
$LANG['setup'][228]="登入欄位"; 
$LANG['setup'][229]="發一個測試郵件到管理員"; 
$LANG['setup'][231]="發送電子郵件的方式"; 
$LANG['setup'][232]="SMTP 主機"; 
$LANG['setup'][234]="SMTP 登入 (選用l)"; 
$LANG['setup'][235]="SMTP 密碼 (選用)"; 
$LANG['setup'][236]="前線工程師負責此問題單"; 
$LANG['setup'][237]="管理員"; 
$LANG['setup'][239]="工程師負責此問題單"; 
$LANG['setup'][240]="通知選項"; 
$LANG['setup'][241]="沒有個人條件。 創建個人參數？"; 
$LANG['setup'][242]="警報選項"; 
$LANG['setup'][243]="消耗品警報"; 
$LANG['setup'][244]="墨水夾警報"; 
$LANG['setup'][245]="回收"; 
$LANG['setup'][246]="合約警報"; 
$LANG['setup'][247]="會計和管理訊息警報"; 
$LANG['setup'][248]="問題單管理群組"; 
$LANG['setup'][249]="請求者群組"; 
$LANG['setup'][250]="預設搜尋域列表"; 
$LANG['setup'][251]="監督群組"; 
$LANG['setup'][252]="選擇顯示預設項目"; 
$LANG['setup'][253]="以群組做搜尋"; 
$LANG['setup'][254]="搜尋方式"; 
$LANG['setup'][255]="群組類別包含此使用者"; 
$LANG['setup'][256]="依使用者"; 
$LANG['setup'][257]="依群組"; 
$LANG['setup'][258]="使用者 & 群組"; 
$LANG['setup'][259]="屬於該群組"; 
$LANG['setup'][260]="使用者類別包含自身群組"; 
$LANG['setup'][261]="群組 DN"; 
$LANG['setup'][262]="使用 DN 做搜尋"; 
$LANG['setup'][263]="依使用者做搜尋篩選"; 
$LANG['setup'][264]="授權過期警報"; 
$LANG['setup'][271]="銀幕管理限制"; 
$LANG['setup'][272]="設備管理限制"; 
$LANG['setup'][273]="電話管理限制"; 
$LANG['setup'][274]="以手動新增"; 
$LANG['setup'][275]="印表機管理限制"; 
$LANG['setup'][280]="自動更新項目並關聯至電腦"; 
$LANG['setup'][281]="連線 / 更新 行為"; 
$LANG['setup'][282]="中斷連線 行為"; 
$LANG['setup'][283]="複製"; 
$LANG['setup'][284]="清除"; 
$LANG['setup'][285]="不要複製"; 
$LANG['setup'][286]="不要刪除"; 
$LANG['setup'][290]="自動傳送電腦"; 
$LANG['setup'][291]="自動傳送電腦模板已在另一個實體"; 
$LANG['setup'][292]="沒有自動傳送"; 
$LANG['setup'][300]="檢查新版本是否可用"; 
$LANG['setup'][301]="新版本是可用的："; 
$LANG['setup'][302]="你可以在GLPI-PROJECT.org 網站找到相關訊息"; 
$LANG['setup'][303]="您擁有最新的可用版本"; 
$LANG['setup'][304]="連線失敗. 如果使用proxy,請設定."; 
$LANG['setup'][305]="每天"; 
$LANG['setup'][306]="檢查升級"; 
$LANG['setup'][307]="從不"; 
$LANG['setup'][308]="每週"; 
$LANG['setup'][309]="每個月"; 
$LANG['setup'][310]="目的地無法連線."; 
$LANG['setup'][311]="代理似服器連線失敗"; 
$LANG['setup'][312]="網頁沒有任何可用資料"; 
$LANG['setup'][313]="注意 : 那裡沒有預設值"; 
$LANG['setup'][314]="網址的最大顯示字元數量"; 
$LANG['setup'][350]="建立問題單的連結項目"; 
$LANG['setup'][351]="所有項目"; 
$LANG['setup'][352]="問題單可連接的項目"; 
$LANG['setup'][360]="自動欄位 (以*標記)"; 
$LANG['setup'][400]="Proxy設定"; 
$LANG['setup'][407]="服務台說明連結"; 
$LANG['setup'][408]="中控台說明連結"; 
$LANG['setup'][409]="當新增問題單文件時加入一個預設的標題"; 
$LANG['setup'][503]="電話模型"; 
$LANG['setup'][504]="電話類型"; 
$LANG['setup'][505]="電話類型的電源"; 
$LANG['setup'][601]="屬性值"; 
$LANG['setup'][603]="新增使用者"; 
$LANG['setup'][604]="與一個組聯合"; 
$LANG['setup'][605]="新增權力給使用者"; 
$LANG['setup'][606]="無法新增,該使用者已存在."; 
$LANG['setup'][607]="和個人檔案建立關聯"; 
$LANG['setup'][608]="預設以軟體關連至問題單"; 
$LANG['setup'][610]="問題單必需要有標題"; 
$LANG['setup'][611]="問題單必需要有內容"; 
$LANG['setup'][612]="問題單必需要有類別"; 
$LANG['setup'][613]="新增一個沒有從一個 LDAP目錄認證的使用者"; 
$LANG['setup'][614]="無法更新登入. 該使用者已存在."; 
$LANG['setup'][615]="問題單的生命週期"; 
$LANG['setup'][616]="自 \ 至"; 
$LANG['setup'][617]="生命週期的問題"; 
$LANG['setup'][618]="生命週期的變化"; 
$LANG['setup'][619]="生命週期"; 
$LANG['setup'][620]="連結"; 
$LANG['setup'][621]="實體的搜索篩選"; 
$LANG['setup'][622]="代表實體的屬性"; 
$LANG['setup'][623]="由LDAP目錄導入實體"; 
$LANG['setup'][624]="連結"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="電子郵件伺服器"; 
$LANG['setup'][661]="無法設定通知：請啟用電子郵件監控"; 
$LANG['setup'][703]="一般"; 
$LANG['setup'][704]="通知"; 
$LANG['setup'][705]="通知"; 
$LANG['setup'][707]="關於預借的警報"; 
$LANG['setup'][708]="尚未解決問題單的警訊,自從"; 
$LANG['setup'][720]="系統信息"; 
$LANG['setup'][721]="系統的安裝和設定資訊"; 
$LANG['setup'][722]="複製/貼上 於您的支援請求"; 
$LANG['setup'][732]="電子郵件服務的網域"; 
$LANG['setup'][800]="Mysql 複製"; 
$LANG['setup'][801]="啟用複製"; 
$LANG['setup'][802]="資料庫"; 
$LANG['setup'][803]="Master 和 Slave之間的差異"; 
$LANG['setup'][804]="使用從站的搜索引擎"; 
$LANG['setup'][805]="永遠"; 
$LANG['setup'][806]="Master 和 Slave間允許最大延遲 (分)"; 
$LANG['setup'][807]="Slave 不同步. 不同的地方:"; 
$LANG['setup'][808]="Slave 資料庫未同步!"; 
$LANG['setup'][809]="MySQL 複製: 唯讀"; 
$LANG['setup'][810]="同步MySQL replication"; 
$LANG['setup'][811]="唯一欄位"; 
$LANG['setup'][813]="不可能紀錄"; 
$LANG['setup'][815]="唯一的欄位(s)"; 
$LANG['setup'][817]="它的強制性選擇一個類型，並且至少要一個欄位"; 
$LANG['setup'][818]="<br/>存在其他項目"; 
$LANG['setup'][819]="更改狀態"; 
$LANG['setup'][820]="垃圾桶中的項目"; 
$LANG['setup'][821]="拒絕記錄到數據庫中"; 
$LANG['setup'][822]="發送通知"; 
$LANG['setup'][823]="項目成功添加，但重複的記錄在"; 
$LANG['setup'][824]="行為人"; 
$LANG['setup'][825]="準備的事"; 
$LANG['setup'][826]="重複"; 
$LANG['setup'][827]="對重複記錄警告"; 
$LANG['setup'][828]="忽略值的唯一性"; 
$LANG['setup'][829]="忽略唯一值"; 
$LANG['setup'][830]="如果同步（更改所有）"; 
$LANG['setup'][831]="如果同步（當前使用者變更）"; 
$LANG['setup'][832]="如果同步或唯讀帳戶"; 

$LANG['sla'][1]="服務等級"; 
$LANG['sla'][2]="最大的解決時間"; 
$LANG['sla'][3]="執行"; 
$LANG['sla'][4]="新增一個上升的等級"; 
$LANG['sla'][5]="到期日"; 
$LANG['sla'][6]="申告等級"; 
$LANG['sla'][8]="下一個申告"; 
$LANG['sla'][9]="服務水平協議自動提醒"; 
$LANG['sla'][10]="24/7"; 
$LANG['sla'][11]="問題單日曆"; 
$LANG['sla'][12]="指定一個 SLA"; 
$LANG['sla'][13]="分配到問題單的 SLA，導致重新計算到期日期."; 
$LANG['sla'][14]="在這個新的日期將觸發在SLA中所定義的升級。"; 
$LANG['sla'][15]="升級層級"; 

$LANG['software'][1]="採購版本"; 
$LANG['software'][2]="使用版本"; 
$LANG['software'][3]="平台"; 
$LANG['software'][4]="無限制"; 
$LANG['software'][5]="版本"; 
$LANG['software'][6]="出版商"; 
$LANG['software'][7]="新增一個版本"; 
$LANG['software'][8]="新增一個授權"; 
$LANG['software'][9]="受影響的電腦"; 
$LANG['software'][10]="軟體創建的實體"; 
$LANG['software'][11]="使用授權"; 
$LANG['software'][12]="授權"; 
$LANG['software'][16]="已安裝的軟體"; 
$LANG['software'][17]="已安裝的軟體"; 
$LANG['software'][19]="安裝"; 
$LANG['software'][20]="殘餘"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="更新"; 
$LANG['software'][30]="授權類型"; 
$LANG['software'][32]="失效"; 
$LANG['software'][44]="安裝軟體"; 
$LANG['software'][45]="移除軟體"; 
$LANG['software'][46]="顯示於服務台"; 
$LANG['software'][47]="合併中"; 
$LANG['software'][48]="合併"; 
$LANG['software'][49]="完成合併後將軟體放進垃圾桶"; 

$LANG['softwarecategories'][2]="展開/關閉軟體目錄清單"; 
$LANG['softwarecategories'][3]="展開沒有類型的軟體"; 
$LANG['softwarecategories'][4]="展開已分類的軟體"; 
$LANG['softwarecategories'][5]="軟體分類"; 
$LANG['softwarecategories'][6]="軟體類別"; 

$LANG['state'][0]="狀態"; 
$LANG['state'][1]="摘要"; 
$LANG['state'][6]="項目類型"; 
$LANG['state'][7]="沒有找到項目"; 

$LANG['stats'][0]="選擇顯示的統計"; 
$LANG['stats'][1]="全部"; 
$LANG['stats'][2]="沒有項目顯示"; 
$LANG['stats'][3]="每個項目"; 
$LANG['stats'][5]="起案的數量"; 
$LANG['stats'][7]="顯示圖形"; 
$LANG['stats'][8]="平均時間"; 
$LANG['stats'][9]="決議"; 
$LANG['stats'][10]="結案"; 
$LANG['stats'][11]="解決的數量"; 
$LANG['stats'][12]="考慮到"; 
$LANG['stats'][13]="問題單的數量"; 
$LANG['stats'][14]="實際的持續時間"; 
$LANG['stats'][15]="問題數量"; 
$LANG['stats'][16]="工程師姓名"; 
$LANG['stats'][17]="已結案的數量"; 
$LANG['stats'][19]="延遲解決的數量"; 
$LANG['stats'][20]="使用者姓名"; 
$LANG['stats'][21]="解決時間"; 
$LANG['stats'][22]="結案時間"; 
$LANG['stats'][23]="沒有可用的統計"; 
$LANG['stats'][24]="考量到帳戶時間"; 
$LANG['stats'][25]="等待時間"; 
$LANG['stats'][26]="(真正的)問題單持續時間"; 
$LANG['stats'][33]="分鐘"; 
$LANG['stats'][34]="秒"; 
$LANG['stats'][35]="問題單"; 
$LANG['stats'][44]="供應廠商名稱"; 
$LANG['stats'][45]="由硬體"; 
$LANG['stats'][46]="依問題"; 
$LANG['stats'][47]="由問題單"; 
$LANG['stats'][48]="(分配)"; 
$LANG['stats'][49]="(作業)"; 

$LANG['title'][5]="知識庫"; 
$LANG['title'][6]="網絡設備"; 
$LANG['title'][9]="項目狀態"; 
$LANG['title'][10]="問題單後續"; 
$LANG['title'][13]="使用者訊息"; 
$LANG['title'][14]="外在認證來源"; 
$LANG['title'][24]="協助"; 
$LANG['title'][26]="主要"; 
$LANG['title'][27]="連接"; 
$LANG['title'][28]="問題單"; 
$LANG['title'][32]="連結"; 
$LANG['title'][33]="外在認證來源"; 
$LANG['title'][34]="連結"; 
$LANG['title'][36]="註解"; 
$LANG['title'][37]="註解s"; 
$LANG['title'][38]="歷史"; 
$LANG['title'][40]="公開和個人註解"; 
$LANG['title'][42]="重大修改"; 
$LANG['title'][43]="註冊"; 

$LANG['tracking'][1]="我的設備"; 
$LANG['tracking'][2]="或完成搜尋"; 
$LANG['tracking'][3]="無效的資料. 取消更新."; 
$LANG['tracking'][4]="您沒有緊急的問題單，請更正。"; 
$LANG['tracking'][5]="將這張問題單與自己關聯"; 
$LANG['tracking'][6]="問題單必需有標題：更新失敗"; 
$LANG['tracking'][7]="問題單必需有描述：更新失敗"; 
$LANG['tracking'][8]="您的問題單沒有任何描述, 請重試."; 
$LANG['tracking'][9]="問題單的預設"; 
$LANG['tracking'][10]="預設郵件收件人"; 
$LANG['tracking'][11]="不詳的問題單"; 
$LANG['tracking'][24]="問題單文件"; 
$LANG['tracking'][29]="數字"; 
$LANG['tracking'][30]="新的"; 
$LANG['tracking'][31]="處理(已指派)"; 
$LANG['tracking'][32]="處理(已計劃)"; 
$LANG['tracking'][34]="直接"; 
$LANG['tracking'][35]="寫入"; 
$LANG['tracking'][37]="當硬體從資產移除後仍保留問題單"; 
$LANG['tracking'][38]="已寄送郵件到"; 
$LANG['tracking'][39]="在簡明介面可視"; 

$LANG['transfer'][1]="移轉"; 
$LANG['transfer'][3]="如果不再使用"; 
$LANG['transfer'][4]="將需移轉的項目由清單中清除"; 
$LANG['transfer'][5]="您可以繼續新增需要移轉的項目或現在就移轉這些項目"; 
$LANG['transfer'][6]="請考慮在移轉前先進行這些項目的備份"; 
$LANG['transfer'][7]="移轉項目"; 
$LANG['transfer'][8]="移轉模式"; 

$LANG['update'][88]="資料庫版本與安裝的檔案不符. 必需更新."; 
$LANG['update'][89]="您嘗試使用舊版本的GLPI連接新版本的GLPI資料庫. 請安裝與目前資料庫版本相符的檔案."; 
$LANG['update'][90]="資料庫更新期間的錯誤"; 
$LANG['update'][91]="注意!"; 
$LANG['update'][92]="您將更新的GLPI資料庫名為："; 
$LANG['update'][93]="資料庫連接成功"; 
$LANG['update'][94]="更新成功，您的資料庫已更新"; 
$LANG['update'][95]="與資料庫的連接失敗，驗證在config_db.php文件中的連線參數"; 
$LANG['update'][96]="所有擁有管理者權限的使用者已被更新為'最高管理者'的權限,以及它所創造新使用者的類型。"; 
$LANG['update'][105]="這樣無法完成更新!!"; 
$LANG['update'][106]="返回到GLPI"; 
$LANG['update'][107]="您必須現在更新您的資料庫內容"; 
$LANG['update'][130]="地點更新"; 
$LANG['update'][131]="新結構是分層的"; 
$LANG['update'][132]="如果您用了一個分隔字元，您可以設置它為自動產生新階層。"; 
$LANG['update'][133]="您也可以指定一個包括所有生成地點的原始地點。"; 
$LANG['update'][134]="分隔字元"; 
$LANG['update'][135]="原始地點"; 
$LANG['update'][136]="這是新增的新階層，如果OK，請確認"; 
$LANG['update'][137]="新增新階層"; 
$LANG['update'][138]="實際地點"; 
$LANG['update'][139]="資料表最佳化"; 
$LANG['update'][140]="創建indexes"; 
$LANG['update'][141]="變更資料庫設計"; 
$LANG['update'][142]="資料移動"; 

$LANG['users'][1]="稱謂"; 
$LANG['users'][2]="類別"; 
$LANG['users'][3]="忘記您的密碼?"; 
$LANG['users'][4]="Token"; 
$LANG['users'][5]="你已經送出重設帳戶密碼要求。"; 
$LANG['users'][6]="只要依照此鏈接（你有一天）："; 
$LANG['users'][7]="請輸入您的電子郵件地址。電子郵件將發送給您，之後你可以選擇一個新密碼。"; 
$LANG['users'][8]="未找到電子郵件地址。"; 
$LANG['users'][9]="身份驗證方法設定不允許您更改密碼。"; 
$LANG['users'][10]="一封電子郵件已經發送到您的電子郵件地址。電子郵件中包含重設密碼的訊息。"; 
$LANG['users'][11]="請確認您的電子郵件地址和新輸入的密碼"; 
$LANG['users'][12]="您的密碼重置請求已過期或無效,請更新密碼."; 
$LANG['users'][13]="重設密碼成功."; 
$LANG['users'][14]="授權"; 
$LANG['users'][15]="從目錄倒入"; 
$LANG['users'][16]="從其它來源導入"; 
$LANG['users'][17]="管理號碼"; 
$LANG['users'][18]="生成於"; 
$LANG['users'][19]="新增至管理者"; 
$LANG['users'][20]="從管理者刪除"; 
$LANG['users'][21]="預設E-mail"; 
$LANG['users'][22]="使用者職稱"; 
$LANG['users'][23]="使用者類別"; 
$LANG['users'][24]="新增至授權債務人"; 
$LANG['users'][25]="從授權債務人刪除"; 

$LANG['validation'][0]="核准"; 
$LANG['validation'][1]="發送核准請求"; 
$LANG['validation'][2]="狀態"; 
$LANG['validation'][3]="申請日期"; 
$LANG['validation'][4]="核准日期"; 
$LANG['validation'][5]="申請說明"; 
$LANG['validation'][6]="核准說明"; 
$LANG['validation'][7]="核准這些問題單"; 
$LANG['validation'][8]="驗證"; 
$LANG['validation'][9]="等待核准"; 
$LANG['validation'][10]="拒絕"; 
$LANG['validation'][11]="准予"; 
$LANG['validation'][12]="不須經批准"; 
$LANG['validation'][13]="核准請求以發送至"; 
$LANG['validation'][15]="待您核准的問題單"; 
$LANG['validation'][16]="核准時可填寫"; 
$LANG['validation'][18]="請求核准者"; 
$LANG['validation'][19]="已准予核准"; 
$LANG['validation'][21]="核准者"; 
$LANG['validation'][23]="所選擇的使用者並沒有可用的電子郵件地址。請求已經建立，但不含電子郵件確認。"; 
$LANG['validation'][25]="全部驗證狀態"; 
$LANG['validation'][26]="請求核准"; 
$LANG['validation'][27]="已送出一個核准申請"; 
$LANG['validation'][28]="核准請求的狀態"; 
$LANG['validation'][29]="如果拒絕核准，明確說明理由"; 
$LANG['validation'][30]="取消核准請求至"; 
$LANG['validation'][31]="更新核准請求至"; 
$LANG['validation'][32]="已同意一個核准申請"; 
$LANG['validation'][33]="待核准的問題單"; 
?>